@@ -20,7 +20,7 @@ PUBLIC_BRIDGE_MTU=${2:-1500}
 export VIRSH_DEFAULT_CONNECT_URI="$LIBVIRT_CONNECT_URI"
 
 # Only add bridge if missing. Bring it UP.
-(sudo ovs-vsctl list-br | grep ${BRIDGE_NAME}$) || sudo ovs-vsctl add-br ${BRIDGE_NAME}
+(sudo ovs-vsctl list-br | grep ${BRIDGE_NAME}) || sudo ovs-vsctl add-br ${BRIDGE_NAME} && ovs-vsctl set Bridge ${BRIDGE_NAME} stp_enable=False && ovs-vsctl set Bridge ${BRIDGE_NAME} rstp_enable=false
 sudo ip link set dev ${BRIDGE_NAME} up
 
 # Remove bridge before replacing it.
