@@ -66,6 +66,19 @@ if  [[ -d $IRONIC_CONF_DIR ]] && [[ ! -d $SAVE_DIR/etc.ironic ]] ; then
     cp -pr $IRONIC_CONF_DIR $SAVE_DIR/etc.ironic
 fi
 
+# Ironic has an early consumer of a new neutron API, and grenade nor devstack
+# has any concept of restarting neutron-rpc-server as it was added in late
+# 2024. Ultimately networking-baremetal adding an rpc call which needs the
+# updated service running means we need to restart it, for now.
+sudo systemctl stop devstack@neutron-rpc-server.service || true
+sudo systemctl stop devstack@q-l3.service || true
+sudo systemctl stop devstack@q-agt.service || true
+sleep 1
+sudo systemctl start devstack@neutron-rpc-server.service || true
+sudo systemctl start devstack@q-l3.service || true
+sudo systemctl start devstack@q-agt.service || true
+sleep 1
+
 stack_install_service ironic
 
 # calls upgrade-ironic for specific release
