@@ -399,6 +399,17 @@ def patched_validate_with_schema(patched_dict, schema, validator=None):
     validator('patch', patched_dict)
 
 
+def allow_special_characters_in_patch_fields():
+    """Check if special characters are allowed in patch field keys."""
+    return (api.request.version.minor
+            >= versions.MINOR_98_SUPPORT_SPECIAL_CHAR_IN_ATTRIBUTES)
+
+
+def decode_json_pointer(path):
+    """Decode JSON pointer as per RFC 6901 to support '~' and '/'."""
+    return path.replace('~1', '/').replace('~0', '~')
+
+
 def patch_validate_allowed_fields(patch, allowed_fields):
     """Validate that a patch list only modifies allowed fields.
 
@@ -410,7 +421,10 @@ def patch_validate_allowed_fields(patch, allowed_fields):
     """
     fields = set()
     for p in patch:
-        path = p['path'].split('/')[1]
+        if allow_special_characters_in_patch_fields():
+            path = decode_json_pointer(p['path'].split('/')[1])
+        else:
+            path = p['path'].split('/')[1]
         if path not in allowed_fields:
             msg = _("Cannot patch %s. Only the following can be updated: %s")
             raise exception.Invalid(
@@ -1621,6 +1635,14 @@ def allow_runbooks():
     return api.request.version.minor >= versions.MINOR_92_RUNBOOKS
 
 
+def allow_inspection_rules():
+    """Check if accessing inspection rule endpoints is allowed.
+
+    Version 1.96 of the API exposed rule endpoints.
+    """
+    return api.request.version.minor >= versions.MINOR_96_INSPECTION_RULES
+
+
 def check_owner_policy(object_type, policy_name, owner, lessee=None,
                        conceal_node=False):
     """Check if the policy authorizes this request on an object.
@@ -2002,6 +2024,7 @@ def check_volume_policy_and_retrieve(policy_name, vol_ident, target=False):
     """
     context = api.request.context
     cdict = context.to_policy_values()
+    rpc_node = None
     owner = None
     lessee = None
     try:
@@ -2063,14 +2086,6 @@ def allow_configdrive_vendor_data():
             >= versions.MINOR_59_CONFIGDRIVE_VENDOR_DATA)
 
 
-def allow_allocation_update():
-    """Check if updating an existing allocation is allowed or not.
-
-    Version 1.57 of the API added support for updating an allocation.
-    """
-    return api.request.version.minor >= versions.MINOR_57_ALLOCATION_UPDATE
-
-
 def allow_allocation_backfill():
     """Check if backfilling allocations is allowed.
 
@@ -2220,3 +2235,27 @@ def allow_get_vmedia():
 def allow_node_ident_as_param_for_port_creation():
     """Check if 'node_ident' parameter is allowed for port creation."""
     return api.request.version.minor >= versions.MINOR_94_PORT_NODENAME
+
+
+def allow_port_description():
+    """Check if description is allowed for ports.
+
+    Version 1.97 of the API added description field to the port object.
+    """
+    return api.request.version.minor >= versions.MINOR_97_PORT_DESCRIPTION
+
+
+def allow_port_vendor():
+    """Check if vendor is allowed for ports.
+
+    Version 1.100 of the API added vendor field to the port object.
+    """
+    return api.request.version.minor >= versions.MINOR_100_PORT_VENDOR
+
+
+def allow_port_category():
+    """Check if category is allowed for ports.
+
+    Version 1.101 of the API added category field to the port object.
+    """
+    return api.request.version.minor >= versions.MINOR_101_PORT_CATEGORY
