@@ -131,6 +131,14 @@ BASE_VERSION = 1
 # v1.91: Remove special treatment of .json for API objects
 # v1.92: Add runbooks API
 # v1.93: Add GET API for virtual media
+# v1.94: Add node name support for port creation
+# v1.95: Add node support for disable_power_off
+# v1.96: Migrate inspection rules from Inspector
+# v1.97: Add description field to port.
+# v1.98: Add support for object attributes with keys containing ~ or /.
+# v1.99: Add conductor group filtering to port and portgroup list
+# v1.100: Add vendor field to port.
+# v1.101: Add category field to port.
 
 MINOR_0_JUNO = 0
 MINOR_1_INITIAL_VERSION = 1
@@ -226,6 +234,14 @@ MINOR_90_OVN_VTEP = 90
 MINOR_91_DOT_JSON = 91
 MINOR_92_RUNBOOKS = 92
 MINOR_93_GET_VMEDIA = 93
+MINOR_94_PORT_NODENAME = 94
+MINOR_95_DISABLE_POWER_OFF = 95
+MINOR_96_INSPECTION_RULES = 96
+MINOR_97_PORT_DESCRIPTION = 97
+MINOR_98_SUPPORT_SPECIAL_CHAR_IN_ATTRIBUTES = 98
+MINOR_99_PORT_PORTGROUP_CONDUCTOR_GROUP_FILTER = 99
+MINOR_100_PORT_VENDOR = 100
+MINOR_101_PORT_CATEGORY = 101
 
 # When adding another version, update:
 # - MINOR_MAX_VERSION
@@ -233,7 +249,8 @@ MINOR_93_GET_VMEDIA = 93
 #   explanation of what changed in the new version
 # - common/release_mappings.py, RELEASE_MAPPING['master']['api']
 
-MINOR_MAX_VERSION = MINOR_93_GET_VMEDIA
+
+MINOR_MAX_VERSION = MINOR_101_PORT_CATEGORY
 
 # String representations of the minor and maximum versions
 _MIN_VERSION_STRING = '{}.{}'.format(BASE_VERSION, MINOR_1_INITIAL_VERSION)
