@@ -14,20 +14,26 @@
 
 """Central place for handling Keystone authorization and service lookup."""
 
+import copy
 import functools
 
 from keystoneauth1 import exceptions as ks_exception
 from keystoneauth1 import loading as ks_loading
 from keystoneauth1 import service_token
 from keystoneauth1 import token_endpoint
+import os_service_types
+from oslo_config import cfg
 from oslo_log import log as logging
 
 from ironic.common import exception
-from ironic.conf import CONF
 
 
 LOG = logging.getLogger(__name__)
 
+DEFAULT_VALID_INTERFACES = ['internal', 'public']
+
+CONF = cfg.CONF
+
 
 def ks_exceptions(f):
     """Wraps keystoneclient functions and centralizes exception handling."""
@@ -157,3 +163,59 @@ def get_service_auth(context, endpoint, service_auth,
         user_auth = service_auth
     return service_token.ServiceTokenAuthWrapper(user_auth=user_auth,
                                                  service_auth=service_auth)
+
+
+def register_auth_opts(conf, group, service_type=None):
+    """Register session- and auth-related options
+
+    Registers only basic auth options shared by all auth plugins.
+    The rest are registered at runtime depending on auth plugin used.
+    """
+    ks_loading.register_session_conf_options(conf, group)
+    ks_loading.register_auth_conf_options(conf, group)
+    CONF.set_default('auth_type', default='password', group=group)
+    ks_loading.register_adapter_conf_options(conf, group)
+    conf.set_default('valid_interfaces', DEFAULT_VALID_INTERFACES, group=group)
+    if service_type:
+        conf.set_default('service_type', service_type, group=group)
+    else:
+        types = os_service_types.get_service_types()
+        key = 'ironic-inspector' if group == 'inspector' else group
+        service_types = types.service_types_by_project.get(key)
+        if service_types:
+            conf.set_default('service_type', service_types[0], group=group)
+
+
+def add_auth_opts(options, service_type=None):
+    """Add auth options to sample config
+
+    As these are dynamically registered at runtime,
+    this adds options for most used auth_plugins
+    when generating sample config.
+    """
+    def add_options(opts, opts_to_add):
+        for new_opt in opts_to_add:
+            for opt in opts:
+                if opt.name == new_opt.name:
+                    break
+            else:
+                opts.append(new_opt)
+
+    opts = copy.deepcopy(options)
+    opts.insert(0, ks_loading.get_auth_common_conf_options()[0])
+    # NOTE(dims): There are a lot of auth plugins, we just generate
+    # the config options for a few common ones
+    plugins = ['password', 'v2password', 'v3password']
+    for name in plugins:
+        plugin = ks_loading.get_plugin_loader(name)
+        add_options(opts, ks_loading.get_auth_plugin_conf_options(plugin))
+    add_options(opts, ks_loading.get_session_conf_options())
+    if service_type:
+        adapter_opts = ks_loading.get_adapter_conf_options(
+            include_deprecated=False)
+        # adding defaults for valid interfaces
+        cfg.set_defaults(adapter_opts, service_type=service_type,
+                         valid_interfaces=DEFAULT_VALID_INTERFACES)
+        add_options(opts, adapter_opts)
+    opts.sort(key=lambda x: x.name)
+    return opts
