@@ -252,6 +252,11 @@ SERVICEHOLD = 'service hold'
 """ Node is being held for direct intervention from a service step. """
 
 
+"""All Node states related to servicing."""
+SERVICING_STATES = frozenset((SERVICING, SERVICEWAIT,
+                              SERVICEFAIL, SERVICEHOLD))
+
+
 # NOTE(kaifeng): INSPECTING is allowed to keep backwards compatibility,
 # starting from API 1.39 node update is disallowed in this state.
 UPDATE_ALLOWED_STATES = (DEPLOYFAIL, INSPECTING, INSPECTFAIL, INSPECTWAIT,
@@ -271,7 +276,8 @@ UNSTABLE_STATES = (DEPLOYING, DEPLOYWAIT, CLEANING, CLEANWAIT, VERIFYING,
 """States that can be changed without external request."""
 
 STUCK_STATES_TREATED_AS_FAIL = (DEPLOYING, CLEANING, VERIFYING, INSPECTING,
-                                ADOPTING, RESCUING, UNRESCUING, DELETING)
+                                ADOPTING, RESCUING, UNRESCUING, DELETING,
+                                SERVICING)
 """States that cannot be resumed once a conductor dies.
 
 If a node gets stuck with one of these states for some reason
@@ -649,6 +655,9 @@ machine.add_transition(SERVICEWAIT, SERVICING, 'resume')
 # A node in service wait can failed
 machine.add_transition(SERVICEWAIT, SERVICEFAIL, 'fail')
 
+# A node in service hold can failed
+machine.add_transition(SERVICEHOLD, SERVICEFAIL, 'fail')
+
 # A node in service wait can be aborted
 machine.add_transition(SERVICEWAIT, SERVICEFAIL, 'abort')
 
@@ -660,3 +669,18 @@ machine.add_transition(SERVICEFAIL, SERVICING, 'service')
 
 # A node in service fail can be rescued
 machine.add_transition(SERVICEFAIL, RESCUING, 'rescue')
+
+# A node in service fail can enter wait state
+machine.add_transition(SERVICEFAIL, SERVICEWAIT, 'wait')
+
+# A node in service fail can be held
+machine.add_transition(SERVICEFAIL, SERVICEHOLD, 'hold')
+
+# A node in service fail may be deleted.
+machine.add_transition(SERVICEFAIL, DELETING, 'delete')
+
+# A node in service fail may be aborted (returned to active)
+machine.add_transition(SERVICEFAIL, ACTIVE, 'abort')
+
+# A node in service wait may be deleted.
+machine.add_transition(SERVICEWAIT, DELETING, 'delete')
