@@ -28,8 +28,14 @@ from ironic import objects
 LOG = log.getLogger(__name__)
 
 
+def get_cleaning_flow(manual_clean=False):
+    return (utils.StepFlow.CLEANING_MANUAL if manual_clean
+            else utils.StepFlow.CLEANING_AUTO)
+
+
 @task_manager.require_exclusive_lock
-def do_node_clean(task, clean_steps=None, disable_ramdisk=False):
+def do_node_clean(task, clean_steps=None, disable_ramdisk=False,
+                  automated_with_steps=False):
     """Internal RPC method to perform cleaning of a node.
 
     :param task: a TaskManager instance with an exclusive lock on its node
@@ -38,10 +44,14 @@ def do_node_clean(task, clean_steps=None, disable_ramdisk=False):
                         For more information, see the clean_steps parameter
                         of :func:`ConductorManager.do_node_clean`.
     :param disable_ramdisk: Whether to skip booting ramdisk for cleaning.
+    :param automated_with_steps: Indicates this is a declarative automated
+                                 clean powered by a runbook.
     """
     node = task.node
-    manual_clean = clean_steps is not None
-    clean_type = 'manual' if manual_clean else 'automated'
+    manual_clean = clean_steps is not None and automated_with_steps is False
+
+    clean_type = get_cleaning_flow(manual_clean)
+
     LOG.debug('Starting %(type)s cleaning for node %(node)s',
               {'type': clean_type, 'node': node.uuid})
 
@@ -77,10 +87,11 @@ def do_node_clean(task, clean_steps=None, disable_ramdisk=False):
         return utils.cleaning_error_handler(task, msg)
 
     utils.wipe_cleaning_internal_info(task)
-    if manual_clean:
+    if clean_steps:
         node.set_driver_internal_info('clean_steps', clean_steps)
         node.set_driver_internal_info('cleaning_disable_ramdisk',
                                       disable_ramdisk)
+        node.set_driver_internal_info('declarative_cleaning', True)
     task.node.save()
 
     utils.node_update_cache(task)
@@ -120,7 +131,9 @@ def do_node_clean(task, clean_steps=None, disable_ramdisk=False):
 
     try:
         conductor_steps.set_node_cleaning_steps(
-            task, disable_ramdisk=disable_ramdisk)
+            task, disable_ramdisk=disable_ramdisk,
+            use_existing_steps=bool(clean_steps)
+        )
     except Exception as e:
         # Catch all exceptions and follow the error handling
         # path so things are cleaned up properly.
@@ -129,6 +142,10 @@ def do_node_clean(task, clean_steps=None, disable_ramdisk=False):
         return utils.cleaning_error_handler(task, msg)
 
     steps = node.driver_internal_info.get('clean_steps', [])
+
+    utils.log_step_flow_history(node=node, flow=clean_type,
+                                steps=steps, status="start")
+
     step_index = 0 if steps else None
     do_next_clean_step(task, step_index, disable_ramdisk=disable_ramdisk)
 
@@ -151,6 +168,9 @@ def do_next_clean_step(task, step_index, disable_ramdisk=None):
     # For manual cleaning, the target provision state is MANAGEABLE,
     # whereas for automated cleaning, it is AVAILABLE.
     manual_clean = node.target_provision_state == states.MANAGEABLE
+
+    clean_type = get_cleaning_flow(manual_clean)
+
     if step_index is None:
         steps = []
     else:
@@ -175,6 +195,11 @@ def do_next_clean_step(task, step_index, disable_ramdisk=None):
         eocn = step.get('execute_on_child_nodes', False)
         result = None
         try:
+            if async_steps.CLEANING_POLLING in node.driver_internal_info:
+                # We're executing a new step, so a prior polling
+                # flag should be dictated by the new step, *not* a
+                # prior step.
+                node.del_driver_internal_info(async_steps.CLEANING_POLLING)
             if not eocn:
                 LOG.info('Executing %(step)s on node %(node)s',
                          {'step': step, 'node': node.uuid})
@@ -223,6 +248,12 @@ def do_next_clean_step(task, step_index, disable_ramdisk=None):
                 task.process_event('wait', target_state=target_state)
                 return
 
+            utils.log_step_flow_history(
+                node=node, flow=clean_type,
+                steps=node.driver_internal_info.get("clean_steps", []),
+                status="end", aborted_step=step.get("step"),
+            )
+
             msg = (_('Node %(node)s failed step %(step)s: '
                      '%(exc)s') %
                    {'node': node.uuid, 'exc': e,
@@ -272,7 +303,15 @@ def do_next_clean_step(task, step_index, disable_ramdisk=None):
             return utils.cleaning_error_handler(task, msg,
                                                 traceback=True,
                                                 tear_down_cleaning=False)
+    utils.node_update_cache(task)
     LOG.info('Node %s cleaning complete', node.uuid)
+
+    utils.log_step_flow_history(
+        node=node, flow=clean_type,
+        steps=node.driver_internal_info.get("clean_steps", []),
+        status="end"
+    )
+
     event = 'manage' if manual_clean or node.retired else 'done'
     # NOTE(rloo): No need to specify target prov. state; we're done
     task.process_event(event)
