@@ -45,7 +45,7 @@ opts = [
                default='auto',
                help=_('Redfish HTTP client authentication method.')),
     cfg.BoolOpt('use_swift',
-                default=True,
+                default=False,
                 mutable=True,
                 help=_('Upload generated ISO images for virtual media boot to '
                        'Swift, then pass temporary URL to BMC for booting the '
@@ -90,6 +90,11 @@ opts = [
                default=60,
                help=_('Number of seconds to wait between checking for '
                       'failed firmware update tasks')),
+    cfg.IntOpt('firmware_update_wait_unresponsive_bmc',
+               min=0,
+               default=300,
+               help=_('Number of seconds to wait before proceeding with the '
+                      'reboot to finish the BMC firmware update step')),
     cfg.StrOpt('firmware_source',
                choices=[('http', _('If firmware source URL is also HTTP, then '
                                    'serve from original location, otherwise '
@@ -121,6 +126,35 @@ opts = [
                help=_('Number of seconds to wait for boot mode or secure '
                       'boot status change to take effect after a reboot. '
                       'Set to 0 to disable waiting.')),
+    cfg.StrOpt('verify_ca',
+               help=_('The default verify_ca path when redfish_verify_ca '
+                      'in driver_info is missing or set to True.')),
+    cfg.BoolOpt('enable_verify_bmc_clock',
+                default=False,
+                help=_('Whether to enable the automated verify step '
+                       'that checks and sets the BMC clock. '
+                       'When enabled, Ironic will automatically attempt '
+                       'to set the BMC\'s clock during node registration '
+                       '(in the verify phase) using Redfish\'s '
+                       'DateTime fields. '
+                       'This helps avoid TLS certificate issues '
+                       'caused by incorrect BMC time.')),
+    cfg.StrOpt('default_inspection_hooks',
+               default='validate-interfaces,ports,architecture',
+               help=_('A comma-separated lists of inspection hooks that are '
+                      'run by default for the "agent" inspection interface. '
+                      'In most cases, the operators will not '
+                      'modify this. The default (somewhat conservative) hooks '
+                      'validate interfaces in the inventory, create '
+                      'ports and set the node\'s cpu architecture property.')),
+    cfg.StrOpt('inspection_hooks',
+               default='$default_inspection_hooks',
+               help=_('Comma-separated list of enabled hooks for processing '
+                      'pipeline when using the "redfish" inspection '
+                      'interface. The default for this is '
+                      '$default_inspection_hooks. Hooks can be added before '
+                      'or after the defaults like this: '
+                      '"prehook,$default_hooks,posthook".')),
 ]
 
 
