@@ -44,8 +44,18 @@ def upgrade():
         sa.Column('candidate_nodes', types.JsonEncodedList(), nullable=True),
         sa.Column('extra', types.JsonEncodedDict(), nullable=True),
         sa.Column('conductor_affinity', sa.Integer(), nullable=True),
-        sa.ForeignKeyConstraint(['conductor_affinity'], ['conductors.id'], ),
-        sa.ForeignKeyConstraint(['node_id'], ['nodes.id'], ),
+        # NOTE(TheJulia): Commenting these out to remove the constraints
+        # as below we link nodes to allocations on a unique foreign key
+        # constraint mapping, and nodes also have the same conductor affinity
+        # constraint, which raises an SAWarning error as sqlalchemy cannot
+        # sort the data model relationships, and expects this to become an
+        # error at some point in the future. As such, since a node is
+        # generally a primary object, and allocations are more secondary
+        # relationship/association mapping objects, the two commented out
+        # lines are redundant. We'll remove the relationships in a migration
+        # as well and ignore errors if they are encountered for new installs.
+        # sa.ForeignKeyConstraint(['conductor_affinity'], ['conductors.id'], ),
+        # sa.ForeignKeyConstraint(['node_id'], ['nodes.id'], ),
         sa.PrimaryKeyConstraint('id'),
         sa.UniqueConstraint('name', name='uniq_allocations0name'),
         sa.UniqueConstraint('uuid', name='uniq_allocations0uuid'),
