@@ -33,7 +33,10 @@ from ironic.drivers.modules.drac import utils as drac_utils
 from ironic.drivers.modules.redfish import raid as redfish_raid
 from ironic.drivers.modules.redfish import utils as redfish_utils
 
-sushy_oem_idrac = importutils.try_import('sushy_oem_idrac')
+try:
+    from sushy.oem import dell as sushy_oem_idrac
+except ModuleNotFoundError:
+    sushy_oem_idrac = importutils.try_import('sushy_oem_idrac')
 
 LOG = logging.getLogger(__name__)
 
