@@ -31,7 +31,8 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
     #              only work with a uuid
     # Version 1.2: Add create() and destroy()
     # Version 1.3: Add list()
-    VERSION = '1.3'
+    # Version 1.4: Relevant methods changed to be remotable methods.
+    VERSION = '1.4'
 
     dbapi = dbapi.get_instance()
 
@@ -42,14 +43,11 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
         'description': object_fields.StringField(nullable=True),
     }
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
-    @classmethod
+    @object_base.remotable_classmethod
     def get(cls, context, chassis_id):
         """Find a chassis based on its id or uuid and return a Chassis object.
 
+        :param context: Security context
         :param chassis_id: the id *or* uuid of a chassis.
         :returns: a :class:`Chassis` object.
         """
@@ -60,46 +58,38 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
         else:
             raise exception.InvalidIdentity(identity=chassis_id)
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
-    @classmethod
+    @object_base.remotable_classmethod
     def get_by_id(cls, context, chassis_id):
-        """Find a chassis based on its integer id and return a Chassis object.
+        """Find a chassis based on its integer ID and return a Chassis object.
 
-        :param chassis_id: the id of a chassis.
+        :param cls: the :class:`Chassis`
+        :param context: Security context
+        :param chassis_id: the ID of a chassis.
         :returns: a :class:`Chassis` object.
         """
         db_chassis = cls.dbapi.get_chassis_by_id(chassis_id)
-        chassis = cls._from_db_object(cls(context), db_chassis)
+        chassis = cls._from_db_object(context, cls(), db_chassis)
         return chassis
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
-    @classmethod
+    @object_base.remotable_classmethod
     def get_by_uuid(cls, context, uuid):
-        """Find a chassis based on uuid and return a :class:`Chassis` object.
+        """Find a chassis based on UUID and return a :class:`Chassis` object.
 
-        :param uuid: the uuid of a chassis.
+        :param cls: the :class:`Chassis`
         :param context: Security context
+        :param uuid: the UUID of a chassis.
         :returns: a :class:`Chassis` object.
         """
         db_chassis = cls.dbapi.get_chassis_by_uuid(uuid)
-        chassis = cls._from_db_object(cls(context), db_chassis)
+        chassis = cls._from_db_object(context, cls(), db_chassis)
         return chassis
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
-    @classmethod
+    @object_base.remotable_classmethod
     def list(cls, context, limit=None, marker=None,
              sort_key=None, sort_dir=None):
         """Return a list of Chassis objects.
 
+        :param cls: the :class:`Chassis`
         :param context: Security context.
         :param limit: maximum number of resources to return in a single result.
         :param marker: pagination marker for large data sets.
@@ -114,10 +104,7 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
                                                 sort_dir=sort_dir)
         return cls._from_db_object_list(context, db_chassis)
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable
+    @object_base.remotable
     def create(self, context=None):
         """Create a Chassis record in the DB.
 
@@ -134,14 +121,11 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
                         object, e.g.: Chassis(context)
 
         """
-        values = self.obj_get_changes()
+        values = self.do_version_changes_for_db()
         db_chassis = self.dbapi.create_chassis(values)
-        self._from_db_object(self, db_chassis)
+        self._from_db_object(self._context, self, db_chassis)
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable
+    @object_base.remotable
     def destroy(self, context=None):
         """Delete the Chassis from the DB.
 
@@ -155,10 +139,7 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
         self.dbapi.destroy_chassis(self.uuid)
         self.obj_reset_changes()
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable
+    @object_base.remotable
     def save(self, context=None):
         """Save updates to this Chassis.
 
@@ -172,14 +153,11 @@ class Chassis(base.IronicObject, object_base.VersionedObjectDictCompat):
                         A context should be set when instantiating the
                         object, e.g.: Chassis(context)
         """
-        updates = self.obj_get_changes()
+        updates = self.do_version_changes_for_db()
         updated_chassis = self.dbapi.update_chassis(self.uuid, updates)
-        self._from_db_object(self, updated_chassis)
+        self._from_db_object(self._context, self, updated_chassis)
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable
+    @object_base.remotable
     def refresh(self, context=None):
         """Loads and applies updates for this Chassis.
 
