@@ -82,7 +82,9 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
     # Version 1.38: Add parent_node field
     # Version 1.39: Add firmware_interface field
     # Version 1.40: Add service_step field
-    VERSION = '1.40'
+    # Version 1.41: Add disable_power_off field
+    # Version 1.42: Moves multiple methods to be remotable methods.
+    VERSION = '1.42'
 
     dbapi = db_api.get_instance()
 
@@ -182,6 +184,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         'secure_boot': object_fields.BooleanField(nullable=True),
         'shard': object_fields.StringField(nullable=True),
         'parent_node': object_fields.StringField(nullable=True),
+        'disable_power_off': objects.fields.BooleanField(nullable=True),
     }
 
     def as_dict(self, secure=False, mask_configdrive=True):
@@ -238,11 +241,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
                 fields=['trait', 'version'])
             self.traits.obj_reset_changes()
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
-    @classmethod
+    @object_base.remotable_classmethod
     def get(cls, context, node_id):
         """Find a node based on its id or uuid and return a Node object.
 
@@ -257,11 +256,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         else:
             raise exception.InvalidIdentity(identity=node_id)
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
-    @classmethod
+    @object_base.remotable_classmethod
     def get_by_id(cls, context, node_id):
         """Find a node based on its integer ID and return a Node object.
 
@@ -274,11 +269,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         node = cls._from_db_object(context, cls(), db_node)
         return node
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
-    @classmethod
+    @object_base.remotable_classmethod
     def get_by_uuid(cls, context, uuid):
         """Find a node based on UUID and return a Node object.
 
@@ -291,11 +282,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         node = cls._from_db_object(context, cls(), db_node)
         return node
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
-    @classmethod
+    @object_base.remotable_classmethod
     def get_by_name(cls, context, name):
         """Find a node based on name and return a Node object.
 
@@ -308,11 +295,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         node = cls._from_db_object(context, cls(), db_node)
         return node
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
-    @classmethod
+    @object_base.remotable_classmethod
     def get_by_instance_uuid(cls, context, instance_uuid):
         """Find a node based on the instance UUID and return a Node object.
 
@@ -325,11 +308,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         node = cls._from_db_object(context, cls(), db_node)
         return node
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
-    @classmethod
+    @object_base.remotable_classmethod
     def list(cls, context, limit=None, marker=None, sort_key=None,
              sort_dir=None, filters=None, fields=None):
         """Return a list of Node objects.
@@ -365,10 +344,9 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
                                            fields=target_fields)
         return cls._from_db_object_list(context, db_nodes, target_fields)
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
+    # NOTE(TheJulia): The choice to not make this a remotable method is
+    # explicit in that locks are intended only for a conductor. If we choose
+    # to change this, we need reconsider the locking model.
     @classmethod
     def reserve(cls, context, tag, node_id):
         """Get and reserve a node.
@@ -388,10 +366,9 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         node = cls._from_db_object(context, cls(), db_node)
         return node
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable_classmethod
+    # NOTE(TheJulia): The choice to not make this a remotable method is
+    # explicit in that locks are intended only for a conductor. If we choose
+    # to change this, we need reconsider the locking model.
     @classmethod
     def release(cls, context, tag, node_id):
         """Release the reservation on a node.
@@ -404,10 +381,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         """
         cls.dbapi.release_node(tag, node_id)
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable
+    @object_base.remotable
     def create(self, context=None):
         """Create a Node record in the DB.
 
@@ -431,10 +405,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         db_node = self.dbapi.create_node(values)
         self._from_db_object(self._context, self, db_node)
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable
+    @object_base.remotable
     def destroy(self, context=None):
         """Delete the Node from the DB.
 
@@ -448,10 +419,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         self.dbapi.destroy_node(self.uuid)
         self.obj_reset_changes()
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable
+    @object_base.remotable
     def save(self, context=None):
         """Save updates to this Node.
 
@@ -517,10 +485,7 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
             utils.validate_conductor_group(fields['conductor_group'])
             fields['conductor_group'] = fields['conductor_group'].lower()
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable
+    @object_base.remotable
     def refresh(self, context=None):
         """Refresh the object by re-fetching from the DB.
 
@@ -535,15 +500,11 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         self.obj_refresh(current)
         self.obj_reset_changes()
 
-    # NOTE(xek): We don't want to enable RPC on this call just yet. Remotable
-    # methods can be used in the future to replace current explicit RPC calls.
-    # Implications of calling new remote procedures should be thought through.
-    # @object_base.remotable
     def touch_provisioning(self, context=None):
         """Touch the database record to mark the provisioning as alive."""
         self.dbapi.touch_node_provisioning(self.id)
 
-    @classmethod
+    @object_base.remotable_classmethod
     def get_by_port_addresses(cls, context, addresses):
         """Get a node by associated port addresses.
 
@@ -695,18 +656,18 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
             self._adjust_field_to_version(name, None, target_version,
                                           1, minor, remove_unavailable_fields)
 
-        # NOTE(dtantsur): the default is False for protected
-        self._adjust_field_to_version('protected', False, target_version,
-                                      1, 29, remove_unavailable_fields)
+        boolean_fields = [('protected', 29, False),
+                          ('retired', 33, False),
+                          ('disable_power_off', 41, False)]
+
+        for name, minor, default in boolean_fields:
+            self._adjust_field_to_version(name, default, target_version,
+                                          1, minor, remove_unavailable_fields)
 
         self._convert_deploy_step_field(target_version,
                                         remove_unavailable_fields)
         self._convert_conductor_group_field(target_version,
                                             remove_unavailable_fields)
-
-        self._adjust_field_to_version('retired', False, target_version,
-                                      1, 33, remove_unavailable_fields)
-
         self._convert_network_data_field(target_version,
                                          remove_unavailable_fields)
 
@@ -771,6 +732,17 @@ class Node(base.IronicObject, object_base.VersionedObjectDictCompat):
         self.properties[key] = value
         self._changed_fields.add('properties')
 
+    def list_child_node_ids(self, exclude_dedicated_power=False):
+        """Returns a list of node IDs for child nodes, if any.
+
+        :param exclude_dedicated_power: Boolean, Default False, if the list
+            should exclude nodes which are independently powered.
+        :returns: A list of any node_id values discovered in the database.
+        """
+        return self.dbapi.get_child_node_ids_by_parent_uuid(
+            self.uuid,
+            exclude_dedicated_power=exclude_dedicated_power)
+
 
 @base.IronicObjectRegistry.register
 class NodePayload(notification.NotificationPayloadBase):
@@ -790,6 +762,7 @@ class NodePayload(notification.NotificationPayloadBase):
         'created_at': ('node', 'created_at'),
         'deploy_step': ('node', 'deploy_step'),
         'description': ('node', 'description'),
+        'disable_power_off': ('node', 'disable_power_off'),
         'driver': ('node', 'driver'),
         'extra': ('node', 'extra'),
         'boot_mode': ('node', 'boot_mode'),
@@ -849,7 +822,8 @@ class NodePayload(notification.NotificationPayloadBase):
     # Version 1.14: Add retired and retired_reason fields exposed via API.
     # Version 1.15: Add node lessee field.
     # Version 1.16: Add boot_mode and secure_boot fields.
-    VERSION = '1.16'
+    # Version 1.17: Add disable_power_off field.
+    VERSION = '1.17'
     fields = {
         'clean_step': object_fields.FlexibleDictField(nullable=True),
         'conductor_group': object_fields.StringField(nullable=True),
@@ -857,6 +831,7 @@ class NodePayload(notification.NotificationPayloadBase):
         'created_at': object_fields.DateTimeField(nullable=True),
         'deploy_step': object_fields.FlexibleDictField(nullable=True),
         'description': object_fields.StringField(nullable=True),
+        'disable_power_off': objects.fields.BooleanField(nullable=True),
         'driver': object_fields.StringField(nullable=True),
         'extra': object_fields.FlexibleDictField(nullable=True),
         'boot_mode': object_fields.StringField(nullable=True),
@@ -941,7 +916,8 @@ class NodeSetPowerStatePayload(NodePayload):
     # Version 1.14: Parent NodePayload version 1.14
     # Version 1.15: Parent NodePayload version 1.15
     # Version 1.16: Parent NodePayload version 1.16
-    VERSION = '1.16'
+    # Version 1.17: Parent NodePayload version 1.17
+    VERSION = '1.17'
 
     fields = {
         # "to_power" indicates the future target_power_state of the node. A
@@ -998,7 +974,8 @@ class NodeCorrectedPowerStatePayload(NodePayload):
     # Version 1.14: Parent NodePayload version 1.14
     # Version 1.15: Parent NodePayload version 1.15
     # Version 1.16: Parent NodePayload version 1.16
-    VERSION = '1.16'
+    # Version 1.17: Parent NodePayload version 1.17
+    VERSION = '1.17'
 
     fields = {
         'from_power': object_fields.StringField(nullable=True)
@@ -1040,7 +1017,8 @@ class NodeSetProvisionStatePayload(NodePayload):
     # Version 1.15: Parent NodePayload version 1.15
     # Version 1.16: add driver_internal_info
     # Version 1.17: Parent NodePayload version 1.16
-    VERSION = '1.17'
+    # Version 1.18: Parent NodePayload version 1.17
+    VERSION = '1.18'
 
     SCHEMA = dict(NodePayload.SCHEMA,
                   **{'instance_info': ('node', 'instance_info'),
@@ -1090,7 +1068,8 @@ class NodeCRUDPayload(NodePayload):
     # Version 1.12: Parent NodePayload version 1.14
     # Version 1.13: Parent NodePayload version 1.15
     # Version 1.14: Parent NodePayload version 1.16
-    VERSION = '1.14'
+    # Version 1.15: Parent NodePayload version 1.17
+    VERSION = '1.15'
 
     SCHEMA = dict(NodePayload.SCHEMA,
                   **{'instance_info': ('node', 'instance_info'),
