@@ -75,12 +75,21 @@ class TestListAllocations(test_api_base.BaseApiTest):
         self.assertNotIn('node_id', data)
 
     def test_get_one_with_json(self):
+        headers = {api_base.Version.string: '1.90'}
         allocation = obj_utils.create_test_allocation(self.context,
                                                       node_id=self.node.id)
         data = self.get_json('/allocations/%s.json' % allocation.uuid,
-                             headers=self.headers)
+                             headers=headers)
         self.assertEqual(allocation.uuid, data['uuid'])
 
+    def test_get_one_with_json_not_found(self):
+        allocation = obj_utils.create_test_allocation(self.context,
+                                                      node_id=self.node.id)
+        data = self.get_json('/allocations/%s.json' % allocation.uuid,
+                             headers=self.headers,
+                             expect_errors=True)
+        self.assertEqual(http_client.NOT_FOUND, data.status_code)
+
     def test_get_one_with_json_in_name(self):
         allocation = obj_utils.create_test_allocation(self.context,
                                                       name='pg.json',
@@ -89,6 +98,14 @@ class TestListAllocations(test_api_base.BaseApiTest):
                              headers=self.headers)
         self.assertEqual(allocation.uuid, data['uuid'])
 
+    def test_get_one_with_double_json_in_name(self):
+        allocation = obj_utils.create_test_allocation(self.context,
+                                                      name='pg.json.json',
+                                                      node_id=self.node.id)
+        data = self.get_json('/allocations/%s' % allocation.uuid,
+                             headers=self.headers)
+        self.assertEqual(allocation.uuid, data['uuid'])
+
     def test_get_one_with_suffix(self):
         allocation = obj_utils.create_test_allocation(self.context,
                                                       name='pg.1',
@@ -1312,10 +1329,16 @@ class TestDelete(test_api_base.BaseApiTest):
         self.assertTrue(mock_destroy.called)
 
     def test_delete_allocation_by_name_with_json(self, mock_destroy):
+        headers = {api_base.Version.string: '1.90'}
         self.delete('/allocations/%s.json' % self.allocation.name,
-                    headers=self.headers)
+                    headers=headers)
         self.assertTrue(mock_destroy.called)
 
+    def test_delete_allocation_by_name_with_json_not_found(self, mock_destroy):
+        res = self.delete('/allocations/%s.json' % self.allocation.name,
+                          headers=self.headers, expect_errors=True)
+        self.assertEqual(http_client.NOT_FOUND, res.status_code)
+
     def test_delete_allocation_by_name_not_existed(self, mock_destroy):
         res = self.delete('/allocations/%s' % 'blah', expect_errors=True,
                           headers=self.headers)
