@@ -84,10 +84,11 @@ class TestListPortgroups(test_api_base.BaseApiTest):
         self.assertNotIn('node_id', data)
 
     def test_get_one_with_json(self):
+        headers = {api_base.Version.string: '1.90'}
         portgroup = obj_utils.create_test_portgroup(self.context,
                                                     node_id=self.node.id)
         data = self.get_json('/portgroups/%s.json' % portgroup.uuid,
-                             headers=self.headers)
+                             headers=headers)
         self.assertEqual(portgroup.uuid, data['uuid'])
 
     def test_get_one_with_json_in_name(self):
@@ -98,6 +99,23 @@ class TestListPortgroups(test_api_base.BaseApiTest):
                              headers=self.headers)
         self.assertEqual(portgroup.uuid, data['uuid'])
 
+    def test_get_one_with_double_json_in_name(self):
+        portgroup = obj_utils.create_test_portgroup(self.context,
+                                                    name='pg.json.json',
+                                                    node_id=self.node.id)
+        data = self.get_json('/portgroups/%s' % portgroup.uuid,
+                             headers=self.headers)
+        self.assertEqual(portgroup.uuid, data['uuid'])
+
+    def test_get_one_with_json_not_found(self):
+        portgroup = obj_utils.create_test_portgroup(self.context,
+                                                    name='pg',
+                                                    node_id=self.node.id)
+        data = self.get_json('/portgroups/%s.json' % portgroup.uuid,
+                             headers=self.headers,
+                             expect_errors=True)
+        self.assertEqual(http_client.NOT_FOUND, data.status_code)
+
     def test_get_one_with_suffix(self):
         portgroup = obj_utils.create_test_portgroup(self.context,
                                                     name='pg.1',
@@ -392,7 +410,7 @@ class TestListPortgroups(test_api_base.BaseApiTest):
             '/portgroups/%s/ports/%s' % (pg.uuid, uuidutils.generate_uuid()),
             headers={api_base.Version.string: str(api_v1.max_version())},
             expect_errors=True)
-        self.assertEqual(http_client.FORBIDDEN, response.status_int)
+        self.assertEqual(http_client.BAD_REQUEST, response.status_int)
 
     def test_ports_subresource_no_portgroups_allowed(self):
         pg = obj_utils.create_test_portgroup(self.context,
@@ -578,6 +596,49 @@ class TestListPortgroups(test_api_base.BaseApiTest):
         self.assertEqual(portgroup.uuid, data['portgroups'][0]['uuid'])
         self.assertEqual(self.node.uuid, data['portgroups'][0]['node_uuid'])
 
+    def test_get_all_by_conductor_groups(self):
+        # Get /v1/portgroups with filter on conductor group
+        node_a = obj_utils.create_test_node(self.context,
+                                            uuid=uuidutils.generate_uuid(),
+                                            conductor_group='group_a')
+        node_b = obj_utils.create_test_node(self.context,
+                                            uuid=uuidutils.generate_uuid(),
+                                            conductor_group='group_b')
+        uuids_group_a = []
+        uuids_group_b = []
+        for i in range(0, 2):
+            portgroup = obj_utils.create_test_portgroup(
+                self.context,
+                node_id=node_a.id,
+                uuid=uuidutils.generate_uuid(),
+                name='foo-%s' % i,
+                address='52:54:00:cf:2d:3%s' % i)
+            uuids_group_a.append(portgroup.uuid)
+        for i in range(3, 6):
+            portgroup = obj_utils.create_test_portgroup(
+                self.context,
+                node_id=node_b.id,
+                uuid=uuidutils.generate_uuid(),
+                name='foo-%s' % i,
+                address='52:54:00:cf:2d:3%s' % i)
+            uuids_group_b.append(portgroup.uuid)
+        data = self.get_json(
+            '/portgroups?conductor_groups=%s' % 'group_a,group_b',
+            headers={api_base.Version.string: str(api_v1.max_version())})
+        self.assertEqual(5, len(data['portgroups']))
+        self.assertJsonEqual(uuids_group_a + uuids_group_b,
+                             [x['uuid'] for x in data['portgroups']])
+        data = self.get_json(
+            '/portgroups?conductor_groups=%s' % 'group_b',
+            headers={api_base.Version.string: str(api_v1.max_version())})
+        self.assertEqual(3, len(data['portgroups']))
+        self.assertJsonEqual(uuids_group_b,
+                             [x['uuid'] for x in data['portgroups']])
+        data = self.get_json(
+            '/portgroups?conductor_groups=%s' % 'no_such_group',
+            headers={api_base.Version.string: str(api_v1.max_version())})
+        self.assertEqual([], data['portgroups'])
+
 
 @mock.patch.object(rpcapi.ConductorAPI, 'update_portgroup', autospec=True)
 class TestPatch(test_api_base.BaseApiTest):
@@ -637,13 +698,14 @@ class TestPatch(test_api_base.BaseApiTest):
 
     def test_update_byname_with_json(self, mock_upd):
         extra = {'foo': 'bar'}
+        headers = {api_base.Version.string: '1.90'}
         mock_upd.return_value = self.portgroup
         mock_upd.return_value.extra = extra
         response = self.patch_json('/portgroups/%s.json' % self.portgroup.name,
                                    [{'path': '/extra/foo',
                                      'value': 'bar',
                                      'op': 'add'}],
-                                   headers=self.headers)
+                                   headers=headers)
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(http_client.OK, response.status_code)
         self.assertEqual(extra, response.json['extra'])
@@ -1413,8 +1475,9 @@ class TestDelete(test_api_base.BaseApiTest):
         self.assertTrue(mock_dpt.called)
 
     def test_delete_portgroup_byname_with_json(self, mock_dpt):
+        headers = {api_base.Version.string: '1.90'}
         self.delete('/portgroups/%s.json' % self.portgroup.name,
-                    headers=self.headers)
+                    headers=headers)
         self.assertTrue(mock_dpt.called)
 
     def test_delete_portgroup_byname_not_existed(self, mock_dpt):
