@@ -353,6 +353,8 @@ class TestListVolumeConnectors(test_api_base.BaseApiTest):
                 node_id = self.node.id
             else:
                 node_id = 100000 + i
+                obj_utils.create_test_node(self.context, id=node_id,
+                                           uuid=uuidutils.generate_uuid())
             obj_utils.create_test_volume_connector(
                 self.context, node_id=node_id,
                 uuid=uuidutils.generate_uuid(),
