@@ -102,7 +102,8 @@ class TestGlanceImageService(base.TestCase):
         fixture = {'name': None,
                    'owner': None,
                    'properties': {},
-                   'status': "active"}
+                   'status': "active",
+                   'visibility': "public"}
         fixture.update(kwargs)
         return openstack.image.v2.image.Image.new(**fixture)
 
@@ -146,7 +147,7 @@ class TestGlanceImageService(base.TestCase):
             'status': "active",
             'tags': [],
             'updated_at': None,
-            'visibility': None,
+            'visibility': "public",
             'os_hash_algo': None,
             'os_hash_value': None,
         }
@@ -188,6 +189,7 @@ class TestGlanceImageService(base.TestCase):
 
         class MyGlanceStubClient(stubs.StubGlanceClient):
             """A client that fails the first time, then succeeds."""
+
             def get_image(self, image_id):
                 if tries[0] == 0:
                     tries[0] = 1
@@ -229,10 +231,12 @@ class TestGlanceImageService(base.TestCase):
                                    'image contains no data',
                                    self.service.download, image_id)
 
+    @mock.patch.object(service_utils, '_GLANCE_SESSION', autospec=True)
     @mock.patch('os.sendfile', autospec=True)
     @mock.patch('os.path.getsize', autospec=True)
     @mock.patch('%s.open' % __name__, new=mock.mock_open(), create=True)
-    def test_download_file_url(self, mock_getsize, mock_sendfile):
+    def test_download_file_url(self, mock_getsize, mock_sendfile,
+                               mock_serviceutils_glance):
         # NOTE: only in v2 API
         class MyGlanceStubClient(stubs.StubGlanceClient):
 
@@ -241,8 +245,9 @@ class TestGlanceImageService(base.TestCase):
             s_tmpfname = '/whatever/source'
 
             def get_image(self, image_id):
+                direct_url = "file://%s" + self.s_tmpfname
                 return type('GlanceTestDirectUrlMeta', (object,),
-                            {'direct_url': 'file://%s' + self.s_tmpfname})
+                            dict(visibility='public', direct_url=direct_url))
 
         stub_context = context.RequestContext(auth_token=True)
         stub_context.user_id = 'fake'
@@ -251,6 +256,7 @@ class TestGlanceImageService(base.TestCase):
 
         stub_service = image_service.GlanceImageService(stub_client,
                                                         context=stub_context)
+        mock_serviceutils_glance.return_value = stub_service
         image_id = uuidutils.generate_uuid()
 
         self.config(allowed_direct_url_schemes=['file'], group='glance')
@@ -278,6 +284,7 @@ class TestGlanceImageService(base.TestCase):
     def test_client_forbidden_converts_to_imagenotauthed(self):
         class MyGlanceStubClient(stubs.StubGlanceClient):
             """A client that raises a Forbidden exception."""
+
             def get_image(self, image_id):
                 raise openstack_exc.ForbiddenException()
 
@@ -295,6 +302,7 @@ class TestGlanceImageService(base.TestCase):
     def test_client_notfound_converts_to_imagenotfound(self):
         class MyGlanceStubClient(stubs.StubGlanceClient):
             """A client that raises a NotFound exception."""
+
             def get_image(self, image_id):
                 raise openstack_exc.NotFoundException()
 
@@ -995,3 +1003,71 @@ class TestServiceUtils(base.TestCase):
         self.assertFalse(service_utils.is_glance_image(image_href))
         image_href = None
         self.assertFalse(service_utils.is_glance_image(image_href))
+
+
+class TestIsImageAvailable(base.TestCase):
+
+    def setUp(self):
+        super(TestIsImageAvailable, self).setUp()
+        self.image = mock.Mock()
+        self.context = context.RequestContext()
+        self.context.roles = []
+
+    def test_allow_access_via_auth_token_enabled(self):
+        self.context.auth_token = 'fake-token'
+        self.config(allow_image_access_via_auth_token=True)
+        self.assertTrue(service_utils.is_image_available(
+            self.context, self.image))
+
+    def test_allow_public_image(self):
+        self.image.visibility = 'public'
+        self.assertTrue(service_utils.is_image_available(
+            self.context, self.image))
+
+    def test_allow_community_image(self):
+        self.image.visibility = 'community'
+        self.assertTrue(service_utils.is_image_available(
+            self.context, self.image))
+
+    def test_allow_admin_if_config_enabled(self):
+        self.context.roles = ['admin']
+        self.config(ignore_project_check_for_admin_tasks=True)
+        self.assertTrue(service_utils.is_image_available(
+            self.context, self.image))
+
+    def test_allow_private_image_owned_by_conductor(self):
+        self.image.visibility = 'private'
+        self.image.owner = service_utils.get_conductor_project_id()
+        self.assertTrue(service_utils.is_image_available(
+            self.context, self.image))
+
+    @mock.patch.object(service_utils, 'get_image_member_list', autospec=True)
+    def test_allow_shared_image_if_member(self, mock_get_members):
+        self.image.visibility = 'shared'
+        self.image.id = 'shared-image-id'
+        self.image.owner = 'some-other-project'
+
+        self.context.project = 'test-project'
+
+        # Mock the conductor project ID and the shared member list
+        conductor_id = service_utils.get_conductor_project_id()
+        mock_get_members.return_value = [conductor_id]
+
+        self.assertTrue(service_utils.is_image_available(
+            self.context, self.image))
+        mock_get_members.assert_called_once_with('shared-image-id',
+                                                 self.context)
+
+    def test_deny_private_image_different_owner(self):
+        self.config(ignore_project_check_for_admin_tasks=False)
+
+        self.image.visibility = 'private'
+        self.image.owner = 'other-owner'
+        self.image.id = 'fake-id'
+
+        self.context.project = 'test-project'
+        self.context.roles = []
+        self.context.auth_token = None
+
+        result = service_utils.is_image_available(self.context, self.image)
+        self.assertFalse(result)
