@@ -84,7 +84,10 @@ class TestService(TestCase):
         super(TestService, self).setUp()
         self.config(auth_strategy='noauth', group='json_rpc')
         self.server_mock = self.useFixture(fixtures.MockPatch(
-            'oslo_service.wsgi.Server', autospec=True)).mock
+            'cheroot.wsgi.Server', autospec=True)).mock
+
+        server_instance = self.server_mock.return_value
+        server_instance.requests = mock.MagicMock()
 
         self.serializer = FakeSerializer()
         self.service = server.WSGIService(FakeManager(), self.serializer,
@@ -140,7 +143,7 @@ class TestService(TestCase):
         # self.config(http_basic_password='myPassword', group='json_rpc')
         self.service = server.WSGIService(FakeManager(), self.serializer,
                                           FakeContext)
-        self.app = self.server_mock.call_args[0][2]
+        self.app = self.server_mock.call_args.kwargs['wsgi_app']
 
     def test_http_basic_not_authenticated(self):
         self._setup_http_basic()
@@ -289,7 +292,7 @@ class TestService(TestCase):
         self.config(auth_strategy='keystone', group='json_rpc')
         self.service = server.WSGIService(FakeManager(), self.serializer,
                                           FakeContext)
-        self.app = self.server_mock.call_args[0][2]
+        self.app = self.server_mock.call_args.kwargs['wsgi_app']
         self._request('success', {'context': self.ctx, 'x': 42},
                       expected_error=401)
 
@@ -298,7 +301,7 @@ class TestService(TestCase):
         self.config(allowed_roles=['allowed', 'ignored'], group='json_rpc')
         self.service = server.WSGIService(FakeManager(), self.serializer,
                                           FakeContext)
-        self.app = self.server_mock.call_args[0][2]
+        self.app = self.server_mock.call_args.kwargs['wsgi_app']
         self._request('success', {'context': self.ctx, 'x': 42},
                       expected_error=401,
                       headers={'Content-Type': 'application/json',
@@ -477,6 +480,24 @@ class TestClient(TestCase):
                   'params': {'answer': 42, 'context': self.ctx_json},
                   'id': self.context.request_id})
 
+    def test_call_with_client_ssl(self, mock_session):
+        self.config(use_ssl=False, client_use_ssl=True, group='json_rpc')
+        response = mock_session.return_value.post.return_value
+        response.json.return_value = {
+            'jsonrpc': '2.0',
+            'result': 42
+        }
+        cctx = self.client.prepare('foo.example.com')
+        self.assertEqual('example.com', cctx.host)
+        result = cctx.call(self.context, 'do_something', answer=42)
+        self.assertEqual(42, result)
+        mock_session.return_value.post.assert_called_once_with(
+            'https://example.com:8089',
+            json={'jsonrpc': '2.0',
+                  'method': 'do_something',
+                  'params': {'answer': 42, 'context': self.ctx_json},
+                  'id': self.context.request_id})
+
     def test_cast_success(self, mock_session):
         cctx = self.client.prepare('foo.example.com')
         self.assertEqual('example.com', cctx.host)
