@@ -224,7 +224,8 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
     @mock.patch.object(neutron, 'update_neutron_port', autospec=True)
     def _test_add_ports_to_network(self, update_mock, is_client_id,
                                    security_groups=None,
-                                   add_all_ports=False):
+                                   add_all_ports=False,
+                                   boot_not_pxe=False):
         # Ports will be created only if pxe_enabled is True
         self.node.network_interface = 'neutron'
         self.node.save()
@@ -263,7 +264,7 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
             expected_create_attrs['extra_dhcp_opts'] = (
                 [{'opt_name': '61', 'opt_value': self._CLIENT_ID}])
 
-        if add_all_ports:
+        if add_all_ports or boot_not_pxe:
             expected_create_attrs2 = copy.deepcopy(expected_create_attrs)
             expected_update_attrs2 = copy.deepcopy(expected_update_attrs)
             expected_update_attrs2['mac_address'] = port2.address
@@ -284,10 +285,13 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
             expected = {port.uuid: self.neutron_port['id']}
 
         with task_manager.acquire(self.context, self.node.uuid) as task:
+            if boot_not_pxe:
+                # force override of driver properties, just to keep it simple.
+                task.driver.boot.capabilities = ['not_pxe']
             ports = neutron.add_ports_to_network(
                 task, self.network_uuid, security_groups=security_groups)
             self.assertEqual(expected, ports)
-            if add_all_ports:
+            if add_all_ports or boot_not_pxe:
                 create_calls = [mock.call(**expected_create_attrs),
                                 mock.call(**expected_create_attrs2)]
                 update_calls = [
@@ -313,6 +317,10 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
                                         security_groups=None,
                                         add_all_ports=True)
 
+    def test_add_ports_to_network_all_ports_via_not_pxe(self):
+        self._test_add_ports_to_network(is_client_id=False,
+                                        boot_not_pxe=True)
+
     @mock.patch.object(neutron, '_verify_security_groups', autospec=True)
     def test_add_ports_to_network_with_sg(self, verify_mock):
         sg_ids = []
@@ -642,6 +650,83 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
 
         self.assertEqual(expected_services, network_data['services'])
 
+    def test_get_neutron_port_data_with_overrides(self):
+
+        mac_addr = "00:11:22:33:44:55"
+        network_data = neutron.get_neutron_port_data('port0', 'vif0',
+                                                     mac_address=mac_addr,
+                                                     iface_type='phy')
+        expected_port = {
+            'id': 'port0',
+            'type': 'phy',
+            'ethernet_mac_address': '00:11:22:33:44:55',
+            'vif_id': '46d4bfb9-b26e-41f3-bd2e-e6dcc1ccedb2',
+            'mtu': 1500
+        }
+
+        self.assertEqual(expected_port, network_data['links'][0])
+
+    def test_get_neutron_port_data_with_bond_links(self):
+        vif_id = 'df5ff3e5-545a-4bb4-91b2-59f96559543e'
+        pg = object_utils.create_test_portgroup(
+            self.context, node_id=self.node.id,
+            uuid='cbc1d358-b19c-4e8e-91a1-6f7a768ca468',
+            extra={'vif_port_id': vif_id})
+        mac_addr = "00:11:22:33:44:55"
+        bond_port_1 = object_utils.create_test_port(
+            self.context, node_id=self.node.id,
+            uuid='f99544f6-1aa2-43db-b41f-c63eb431e559',
+            address=mac_addr,
+            portgroup_id=pg.id)
+        bond_port_2 = object_utils.create_test_port(
+            self.context, node_id=self.node.id,
+            uuid='6fc5ac99-6919-4789-a6bf-4906baca5da4',
+            address='aa:bb:cc:dd:ee:ff',
+            portgroup_id=pg.id)
+        # Bond links in this case are supplied by the caller, but
+        # we need to pass something through and validate data is
+        # injected in to the result.
+        bond_links = [
+            {
+                'id': str(bond_port_1.id),
+                'type': 'phy',
+                'ethernet_mac_address': bond_port_1.address,
+            },
+            {
+                'id': str(bond_port_2.id),
+                'type': 'phy',
+                'ethernet_mac_address': bond_port_2.address,
+            }
+        ]
+
+        network_data = neutron.get_neutron_port_data('port0', 'vif0',
+                                                     mac_address=mac_addr,
+                                                     iface_type='phy',
+                                                     bond_links=bond_links)
+
+        expected_links = [
+            {
+                'bond_links': ["2", "3"],
+                'ethernet_mac_address': '00:11:22:33:44:55',
+                'id': 'port0',
+                'mtu': 1500,
+                'type': 'bond',
+                'vif_id': '46d4bfb9-b26e-41f3-bd2e-e6dcc1ccedb2'
+            },
+            {
+                'ethernet_mac_address': '00:11:22:33:44:55',
+                'id': "2",
+                'type': 'phy'
+            },
+            {
+                'ethernet_mac_address': 'aa:bb:cc:dd:ee:ff',
+                'id': "3",
+                'type': 'phy'
+            }
+        ]
+
+        self.assertEqual(expected_links, network_data['links'])
+
     def load_ipv6_files(self):
         port_show_file = os.path.join(
             os.path.dirname(__file__), 'json_samples',
@@ -1018,7 +1103,8 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
             wait_agent_mock.assert_called_once_with(
                 self.client_mock, 'hostname')
             wait_port_mock.assert_called_once_with(
-                self.client_mock, self.neutron_port.id, 'ACTIVE')
+                self.client_mock, self.neutron_port.id, 'ACTIVE',
+                fail_on_binding_failure=True)
 
     @mock.patch.object(neutron, 'is_smartnic_port', autospec=True)
     @mock.patch.object(neutron, 'wait_for_host_agent', autospec=True)
@@ -1246,6 +1332,78 @@ class TestUnbindPort(base.TestCase):
         mock_log.info.assert_called_once_with('Port %s was not found while '
                                               'unbinding.', port_id)
 
+    @mock.patch.object(neutron, 'get_client', autospec=True)
+    def test_unbind_neutron_port_if_bound(self, mock_client, mock_unp):
+        fake_client = mock.Mock()
+        fake_client.get_port.return_value.binding_host_id = 'foo'
+        mock_client.return_value = fake_client
+        port_id = 'fake-port-id'
+        neutron.unbind_neutron_port_if_bound(port_id, context=self.context)
+        mock_client.assert_called_once_with(context=self.context)
+        fake_client.get_port.assert_called_once_with(port_id)
+        mock_unp.assert_has_calls([
+            mock.call(None, 'fake-port-id',
+                      {'binding:host_id': '', 'binding:profile': {}},
+                      None),
+            mock.call(None, 'fake-port-id',
+                      {'mac_address': None},
+                      None)
+        ])
+
+    @mock.patch.object(neutron, 'get_client', autospec=True)
+    def test_unbind_neutron_port_if_bound_not_bound(self, mock_client,
+                                                    mock_unp):
+        fake_client = mock.Mock()
+        fake_client.get_port.return_value.binding_host_id = None
+        mock_client.return_value = fake_client
+        port_id = 'fake-port-id'
+        neutron.unbind_neutron_port_if_bound(port_id, context=self.context)
+        mock_client.assert_called_once_with(context=self.context)
+        fake_client.get_port.assert_called_once_with(port_id)
+        mock_unp.assert_not_called()
+
+    @mock.patch.object(neutron, 'get_client', autospec=True)
+    def test_unbind_neutron_port_if_bound_not_bound_empty(self, mock_client,
+                                                          mock_unp):
+        fake_client = mock.Mock()
+        # While it should be none, it can be set to empty value.
+        fake_client.get_port.return_value.binding_host_id = ''
+        mock_client.return_value = fake_client
+        port_id = 'fake-port-id'
+        neutron.unbind_neutron_port_if_bound(port_id, context=self.context)
+        mock_client.assert_called_once_with(context=self.context)
+        fake_client.get_port.assert_called_once_with(port_id)
+        mock_unp.assert_not_called()
+
+    @mock.patch.object(neutron, 'get_client', autospec=True)
+    def test_unbind_neutron_port_if_bound_port_not_found(self, mock_client,
+                                                         mock_unp):
+        fake_client = mock.Mock()
+        fake_client.get_port.side_effect = openstack_exc.ResourceNotFound()
+        mock_client.return_value = fake_client
+        port_id = 'fake-port-id'
+        self.assertRaises(exception.NetworkError,
+                          neutron.unbind_neutron_port_if_bound,
+                          port_id, context=self.context)
+        mock_client.assert_called_once_with(context=self.context)
+        fake_client.get_port.assert_called_once_with(port_id)
+        mock_unp.assert_not_called()
+
+    @mock.patch.object(neutron, 'get_client', autospec=True)
+    def test_unbind_neutron_port_if_bound_port_osc_error(self, mock_client,
+                                                         mock_unp):
+        fake_client = mock.Mock()
+        fake_client.get_port.side_effect = (
+            openstack_exc.OpenStackCloudException())
+        mock_client.return_value = fake_client
+        port_id = 'fake-port-id'
+        self.assertRaises(exception.NetworkError,
+                          neutron.unbind_neutron_port_if_bound,
+                          port_id, context=self.context)
+        mock_client.assert_called_once_with(context=self.context)
+        fake_client.get_port.assert_called_once_with(port_id)
+        mock_unp.assert_not_called()
+
 
 class TestGetNetworkByUUIDOrName(base.TestCase):
 
