@@ -439,7 +439,8 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
         node.refresh()
         self.assertEqual(states.CLEANFAIL, node.provision_state)
         self.assertEqual(tgt_prov_state, node.target_provision_state)
-        mock_steps.assert_called_once_with(mock.ANY, disable_ramdisk=False)
+        mock_steps.assert_called_once_with(mock.ANY, disable_ramdisk=False,
+                                           use_existing_steps=mock.ANY)
         self.assertFalse(node.maintenance)
         self.assertIsNone(node.fault)
 
@@ -470,7 +471,8 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
         node.refresh()
         self.assertEqual(states.CLEANFAIL, node.provision_state)
         self.assertEqual(tgt_prov_state, node.target_provision_state)
-        mock_steps.assert_called_once_with(mock.ANY, disable_ramdisk=False)
+        mock_steps.assert_called_once_with(mock.ANY, disable_ramdisk=False,
+                                           use_existing_steps=mock.ANY)
         self.assertTrue(mock_power.called)
 
     def test__do_node_clean_automated_steps_fail(self):
@@ -491,13 +493,13 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
                 autospec=True)
     def __do_node_clean(self, mock_power_valid, mock_network_valid,
                         mock_next_step, mock_steps, clean_steps=None,
-                        disable_ramdisk=False):
-        if clean_steps:
+                        disable_ramdisk=False, automated_with_steps=False):
+        if clean_steps and not automated_with_steps:
             tgt_prov_state = states.MANAGEABLE
         else:
             tgt_prov_state = states.AVAILABLE
 
-            def set_steps(task, disable_ramdisk=None):
+            def set_steps(task, disable_ramdisk=None, use_existing_steps=None):
                 dii = task.node.driver_internal_info
                 dii['clean_steps'] = self.clean_steps
                 task.node.driver_internal_info = dii
@@ -516,7 +518,8 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
         with task_manager.acquire(
                 self.context, node.uuid, shared=False) as task:
             cleaning.do_node_clean(task, clean_steps=clean_steps,
-                                   disable_ramdisk=disable_ramdisk)
+                                   disable_ramdisk=disable_ramdisk,
+                                   automated_with_steps=automated_with_steps)
 
             node.refresh()
 
@@ -529,7 +532,8 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
             mock_next_step.assert_called_once_with(
                 task, 0, disable_ramdisk=disable_ramdisk)
             mock_steps.assert_called_once_with(
-                task, disable_ramdisk=disable_ramdisk)
+                task, disable_ramdisk=disable_ramdisk,
+                use_existing_steps=mock.ANY)
             if clean_steps:
                 self.assertEqual(clean_steps,
                                  node.driver_internal_info['clean_steps'])
@@ -1204,6 +1208,12 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
     def test_continue_node_clean_no_skip_step(self):
         self._continue_node_clean(skip=False)
 
+    def test__do_node_clean_automated_with_steps(self):
+        """Test automated cleaning with steps from runbook."""
+        self.__do_node_clean(
+            clean_steps=self.clean_steps,
+            automated_with_steps=True)
+
 
 class DoNodeCleanAbortTestCase(db_base.DbTestCase):
     @mock.patch.object(fake.FakeDeploy, 'tear_down_cleaning', autospec=True)
@@ -1291,8 +1301,8 @@ class DoNodeCleanTestChildNodes(db_base.DbTestCase):
     def setUp(self):
         super(DoNodeCleanTestChildNodes, self).setUp()
         self.config(automated_clean=True, group='conductor')
-        self.power_off_parent = {
-            'step': 'power_off', 'priority': 4, 'interface': 'power'}
+        self.power_on_parent = {
+            'step': 'power_on', 'priority': 4, 'interface': 'power'}
         self.power_on_children = {
             'step': 'power_on', 'priority': 5, 'interface': 'power',
             'execute_on_child_nodes': True}
@@ -1305,7 +1315,7 @@ class DoNodeCleanTestChildNodes(db_base.DbTestCase):
         self.power_on_parent = {
             'step': 'power_on', 'priority': 15, 'interface': 'power'}
         self.clean_steps = [
-            self.power_off_parent,
+            self.power_on_parent,
             self.power_on_children,
             self.update_firmware_on_children,
             self.reboot_children,
@@ -1319,6 +1329,8 @@ class DoNodeCleanTestChildNodes(db_base.DbTestCase):
             driver_internal_info={'agent_secret_token': 'old',
                                   'clean_steps': self.clean_steps})
 
+    @mock.patch('ironic.drivers.modules.fake.FakePower.get_power_state',
+                autospec=True)
     @mock.patch('ironic.drivers.modules.fake.FakePower.reboot',
                 autospec=True)
     @mock.patch('ironic.drivers.modules.fake.FakePower.set_power_state',
@@ -1335,7 +1347,7 @@ class DoNodeCleanTestChildNodes(db_base.DbTestCase):
                 autospec=True)
     def test_do_next_clean_step_with_children(
             self, mock_deploy, mock_mgmt, mock_power, mock_pv, mock_nv,
-            mock_sps, mock_reboot):
+            mock_sps, mock_reboot, mock_gps):
         child_node1 = obj_utils.create_test_node(
             self.context,
             uuid=uuidutils.generate_uuid(),
@@ -1350,7 +1362,12 @@ class DoNodeCleanTestChildNodes(db_base.DbTestCase):
             last_error=None,
             power_state=states.POWER_OFF,
             parent_node=self.node.uuid)
-
+        mock_gps.side_effect = [states.POWER_OFF,
+                                states.POWER_ON,
+                                states.POWER_OFF,
+                                states.POWER_ON,
+                                states.POWER_OFF,
+                                states.POWER_ON]
         mock_deploy.return_value = None
         mock_mgmt.return_value = None
         mock_power.return_value = None
@@ -1382,13 +1399,15 @@ class DoNodeCleanTestChildNodes(db_base.DbTestCase):
         self.assertEqual(0, mock_power.call_count)
         self.assertEqual(0, mock_nv.call_count)
         self.assertEqual(0, mock_pv.call_count)
-        self.assertEqual(4, mock_sps.call_count)
+        self.assertEqual(3, mock_sps.call_count)
         self.assertEqual(2, mock_reboot.call_count)
         mock_sps.assert_has_calls([
-            mock.call(mock.ANY, mock.ANY, 'power off', timeout=None),
+            mock.call(mock.ANY, mock.ANY, 'power on', timeout=None),
             mock.call(mock.ANY, mock.ANY, 'power on', timeout=None),
             mock.call(mock.ANY, mock.ANY, 'power on', timeout=None)])
 
+    @mock.patch('ironic.drivers.modules.fake.FakePower.get_power_state',
+                autospec=True)
     @mock.patch('ironic.drivers.modules.fake.FakePower.set_power_state',
                 autospec=True)
     @mock.patch('ironic.drivers.modules.network.flat.FlatNetwork.validate',
@@ -1403,7 +1422,7 @@ class DoNodeCleanTestChildNodes(db_base.DbTestCase):
                 autospec=True)
     def test_do_next_clean_step_with_children_by_uuid(
             self, mock_deploy, mock_mgmt, mock_power, mock_pv, mock_nv,
-            mock_sps):
+            mock_sps, mock_gps):
         child_node1 = obj_utils.create_test_node(
             self.context,
             uuid=uuidutils.generate_uuid(),
@@ -1416,6 +1435,10 @@ class DoNodeCleanTestChildNodes(db_base.DbTestCase):
             driver='fake-hardware',
             last_error=None,
             parent_node=self.node.uuid)
+        # NOTE(TheJulia): This sets the stage for the test,
+        # child node power is off, parent node power is on.
+        mock_gps.side_effect = [states.POWER_OFF,
+                                states.POWER_ON]
         power_on_children = {
             'step': 'power_on', 'priority': 5, 'interface': 'power',
             'execute_on_child_nodes': True,
