@@ -949,6 +949,32 @@ class DoNodeServiceTestCase(db_base.DbTestCase):
         # Start is the continuation from a heartbeat.
         self._test_do_next_service_step_handles_hold(states.SERVICEWAIT)
 
+    def test_do_next_service_step_handles_hold_from_failed(self):
+        # Test that hold step from SERVICEFAIL transitions to SERVICEHOLD
+        self._test_do_next_service_step_handles_hold(states.SERVICEFAIL)
+
+    def test_do_next_service_step_handles_wait_from_failed(self):
+        # Test that wait step from SERVICEFAIL transitions to SERVICEWAIT
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.SERVICEFAIL,
+            driver_internal_info={
+                'service_steps': [
+                    {
+                        'step': 'wait',
+                        'priority': 10,
+                        'interface': 'power'
+                    }
+                ],
+                'service_step_index': None},
+            service_step=None)
+
+        with task_manager.acquire(
+                self.context, node.uuid, shared=False) as task:
+            servicing.do_next_service_step(task, 0)
+        node.refresh()
+        self.assertEqual(states.SERVICEWAIT, node.provision_state)
+
     @mock.patch.object(servicing, 'do_next_service_step', autospec=True)
     def _continue_node_service(self, mock_next_step, skip=True):
         # test that skipping current step mechanism works
@@ -991,6 +1017,7 @@ class DoNodeServiceAbortTestCase(db_base.DbTestCase):
             driver_internal_info={
                 'agent_url': 'some url',
                 'agent_secret_token': 'token',
+                'agent_start_attempted': True,
                 'service_step_index': 2,
                 'servicing_reboot': True,
                 'servicing_polling': True,
@@ -1061,6 +1088,46 @@ class DoNodeServiceAbortTestCase(db_base.DbTestCase):
             self.assertTrue(task.node.maintenance)
             self.assertEqual('service failure', task.node.fault)
 
+    @mock.patch.object(fake.FakeBoot, 'prepare_instance', autospec=True)
+    @mock.patch.object(fake.FakePower, 'set_power_state', autospec=True)
+    @mock.patch.object(fake.FakeDeploy, 'tear_down_service', autospec=True)
+    def test_do_node_service_abort_agent_attempted(self, tear_mock, power_mock,
+                                                   prepare_mock):
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.SERVICEWAIT,
+            target_provision_state=states.AVAILABLE,
+            driver_internal_info={
+                'agent_start_attempted': True,
+                'service_step_index': 2})
+
+        with task_manager.acquire(self.context, node.uuid) as task:
+            servicing.do_node_service_abort(task)
+            tear_mock.assert_called_once_with(mock.ANY, task)
+            prepare_mock.assert_called_once_with(mock.ANY, task)
+            power_mock.assert_has_calls([
+                mock.call(mock.ANY, task, 'power off'),
+                mock.call(mock.ANY, task, 'power on')])
+
+    @mock.patch.object(fake.FakeBoot, 'prepare_instance', autospec=True)
+    @mock.patch.object(fake.FakePower, 'set_power_state', autospec=True)
+    @mock.patch.object(fake.FakeDeploy, 'tear_down_service', autospec=True)
+    def test_do_node_service_abort_agent_not_attempted(self, tear_mock,
+                                                       power_mock,
+                                                       prepare_mock):
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.SERVICEWAIT,
+            target_provision_state=states.AVAILABLE,
+            driver_internal_info={
+                'service_step_index': 2})
+
+        with task_manager.acquire(self.context, node.uuid) as task:
+            servicing.do_node_service_abort(task)
+            tear_mock.assert_called_once_with(mock.ANY, task)
+            prepare_mock.assert_not_called()
+            power_mock.assert_not_called()
+
 
 class DoNodeCleanTestChildNodes(db_base.DbTestCase):
     def setUp(self):
