@@ -16,7 +16,7 @@
 
 from unittest import mock
 
-from neutronclient.common import exceptions as neutron_client_exc
+from openstack.connection import exceptions as openstack_exc
 from oslo_utils import uuidutils
 
 from ironic.common import dhcp_factory
@@ -59,7 +59,7 @@ class TestNeutron(db_base.DbTestCase):
                 {'opt_name': 'server-ip-address',
                  'opt_value': '1.1.1.1'}]
         port_id = 'fake-port-id'
-        expected = {'port': {'extra_dhcp_opts': opts}}
+        expected = {'extra_dhcp_opts': opts}
         port_data = {
             "id": port_id,
             "fixed_ips": [
@@ -68,7 +68,7 @@ class TestNeutron(db_base.DbTestCase):
                 }
             ],
         }
-        client_mock.return_value.show_port.return_value = {'port': port_data}
+        client_mock.return_value.get_port.return_value = port_data
 
         api = dhcp_factory.DHCPFactory()
         with task_manager.acquire(self.context, self.node.uuid) as task:
@@ -94,12 +94,13 @@ class TestNeutron(db_base.DbTestCase):
                  'ip_version': 6}]
         port_id = 'fake-port-id'
         expected = {
-            'port': {
-                'extra_dhcp_opts': [{
+            'extra_dhcp_opts': [
+                {
                     'opt_name': 'bootfile-url',
                     'opt_value': 'tftp://::1/file.name',
-                    'ip_version': 6}]
-            }
+                    'ip_version': 6
+                }
+            ]
         }
         port_data = {
             "id": port_id,
@@ -109,7 +110,73 @@ class TestNeutron(db_base.DbTestCase):
                 }
             ],
         }
-        client_mock.return_value.show_port.return_value = {'port': port_data}
+        client_mock.return_value.get_port.return_value = port_data
+
+        api = dhcp_factory.DHCPFactory()
+        with task_manager.acquire(self.context, self.node.uuid) as task:
+            api.provider.update_port_dhcp_opts(port_id, opts,
+                                               context=task.context)
+        update_mock.assert_called_once_with(
+            task.context, port_id, expected)
+
+    @mock.patch('ironic.common.neutron.get_client', autospec=True)
+    @mock.patch('ironic.common.neutron.update_neutron_port', autospec=True)
+    def test_update_port_dhcp_opts_v4_and_v6(self, update_mock, client_mock):
+        opts = [{'opt_name': 'bootfile-name',
+                 'opt_value': 'pxelinux.0',
+                 'ip_version': 4},
+                {'opt_name': 'tftp-server',
+                 'opt_value': '1.1.1.1',
+                 'ip_version': 4},
+                {'opt_name': 'server-ip-address',
+                 'opt_value': '1.1.1.1',
+                 'ip_version': 4},
+                {'opt_name': 'bootfile-url',
+                 'opt_value': 'tftp://::1/file.name',
+                 'ip_version': 6}]
+        port_id = 'fake-port-id'
+        expected = {
+            'extra_dhcp_opts': [
+                {
+                    'opt_name': 'bootfile-name',
+                    'opt_value': 'pxelinux.0',
+                    'ip_version': 4
+                },
+                {
+                    'opt_name': 'tftp-server',
+                    'opt_value': '1.1.1.1',
+                    'ip_version': 4
+                },
+                {
+                    'opt_name': 'server-ip-address',
+                    'opt_value': '1.1.1.1',
+                    'ip_version': 4
+                },
+                {
+                    'opt_name': 'bootfile-url',
+                    'opt_value': 'tftp://::1/file.name',
+                    'ip_version': 6
+                }
+            ]
+        }
+        port_data = {
+            "id": port_id,
+            "fixed_ips": [
+                {
+                    "ip_address": "192.168.1.3",
+                },
+                {
+                    "ip_address": "192.168.1.4",
+                },
+                {
+                    "ip_address": "2001:db8::201",
+                },
+                {
+                    "ip_address": "2001:db8::202",
+                }
+            ],
+        }
+        client_mock.return_value.get_port.return_value = port_data
 
         api = dhcp_factory.DHCPFactory()
         with task_manager.acquire(self.context, self.node.uuid) as task:
@@ -132,9 +199,8 @@ class TestNeutron(db_base.DbTestCase):
                 }
             ],
         }
-        client_mock.return_value.show_port.return_value = {'port': port_data}
-        update_mock.side_effect = (
-            neutron_client_exc.NeutronClientException())
+        client_mock.return_value.get_port.return_value = port_data
+        update_mock.side_effect = openstack_exc.OpenStackCloudException()
 
         api = dhcp_factory.DHCPFactory()
         with task_manager.acquire(self.context, self.node.uuid) as task:
@@ -262,10 +328,10 @@ class TestNeutron(db_base.DbTestCase):
             "device_id": 'bece68a3-2f8b-4e66-9092-244493d6aba7',
         }
         fake_client = mock.Mock()
-        fake_client.show_port.return_value = {'port': port_data}
+        fake_client.get_port.return_value = port_data
         result = api._get_fixed_ip_address(port_id, fake_client)
         self.assertEqual(expected, result)
-        fake_client.show_port.assert_called_once_with(port_id)
+        fake_client.get_port.assert_called_once_with(port_id)
 
     def test__get_fixed_ip_address_ipv6(self):
         port_id = 'fake-port-id'
@@ -286,10 +352,10 @@ class TestNeutron(db_base.DbTestCase):
             "device_id": 'bece68a3-2f8b-4e66-9092-244493d6aba7',
         }
         fake_client = mock.Mock()
-        fake_client.show_port.return_value = {'port': port_data}
+        fake_client.get_port.return_value = port_data
         result = api._get_fixed_ip_address(port_id, fake_client)
         self.assertEqual(expected, result)
-        fake_client.show_port.assert_called_once_with(port_id)
+        fake_client.get_port.assert_called_once_with(port_id)
 
     def test__get_fixed_ip_address_invalid_ip(self):
         port_id = 'fake-port-id'
@@ -309,22 +375,23 @@ class TestNeutron(db_base.DbTestCase):
             "device_id": 'bece68a3-2f8b-4e66-9092-244493d6aba7',
         }
         fake_client = mock.Mock()
-        fake_client.show_port.return_value = {'port': port_data}
+        fake_client.get_port.return_value = port_data
         self.assertRaises(exception.InvalidIPAddress,
                           api._get_fixed_ip_address,
                           port_id, fake_client)
-        fake_client.show_port.assert_called_once_with(port_id)
+        fake_client.get_port.assert_called_once_with(port_id)
 
     def test__get_fixed_ip_address_with_exception(self):
         port_id = 'fake-port-id'
         api = dhcp_factory.DHCPFactory().provider
 
         fake_client = mock.Mock()
-        fake_client.show_port.side_effect = (
-            neutron_client_exc.NeutronClientException())
+        fake_client.get_port.side_effect = (
+            openstack_exc.OpenStackCloudException())
+
         self.assertRaises(exception.NetworkError,
                           api._get_fixed_ip_address, port_id, fake_client)
-        fake_client.show_port.assert_called_once_with(port_id)
+        fake_client.get_port.assert_called_once_with(port_id)
 
     @mock.patch('ironic.dhcp.neutron.NeutronDHCPApi._get_fixed_ip_address',
                 autospec=True)
@@ -416,11 +483,8 @@ class TestNeutron(db_base.DbTestCase):
 
     @mock.patch('ironic.dhcp.neutron.NeutronDHCPApi._get_fixed_ip_address',
                 autospec=True)
-    def _test__get_ip_addresses_ports(self, key, mock_gfia):
-        if key == "extra":
-            kwargs1 = {key: {'vif_port_id': 'test-vif-A'}}
-        else:
-            kwargs1 = {key: {'tenant_vif_port_id': 'test-vif-A'}}
+    def test__get_ip_addresses_ports_int_info(self, mock_gfia):
+        kwargs1 = {'internal_info': {'tenant_vif_port_id': 'test-vif-A'}}
         ip_address = '10.10.0.1'
         expected = [ip_address]
         port = object_utils.create_test_port(self.context,
@@ -435,19 +499,10 @@ class TestNeutron(db_base.DbTestCase):
                                            mock.sentinel.client)
         self.assertEqual(expected, result)
 
-    def test__get_ip_addresses_ports_extra(self):
-        self._test__get_ip_addresses_ports('extra')
-
-    def test__get_ip_addresses_ports_int_info(self):
-        self._test__get_ip_addresses_ports('internal_info')
-
     @mock.patch('ironic.dhcp.neutron.NeutronDHCPApi._get_fixed_ip_address',
                 autospec=True)
-    def _test__get_ip_addresses_portgroup(self, key, mock_gfia):
-        if key == "extra":
-            kwargs1 = {key: {'vif_port_id': 'test-vif-A'}}
-        else:
-            kwargs1 = {key: {'tenant_vif_port_id': 'test-vif-A'}}
+    def test__get_ip_addresses_portgroup_int_info(self, mock_gfia):
+        kwargs1 = {'internal_info': {'tenant_vif_port_id': 'test-vif-A'}}
         ip_address = '10.10.0.1'
         expected = [ip_address]
         pg = object_utils.create_test_portgroup(
@@ -460,12 +515,6 @@ class TestNeutron(db_base.DbTestCase):
             result = api._get_ip_addresses(task, [pg], mock.sentinel.client)
         self.assertEqual(expected, result)
 
-    def test__get_ip_addresses_portgroup_extra(self):
-        self._test__get_ip_addresses_portgroup('extra')
-
-    def test__get_ip_addresses_portgroup_int_info(self):
-        self._test__get_ip_addresses_portgroup('internal_info')
-
     @mock.patch('ironic.common.neutron.get_client', autospec=True)
     @mock.patch('ironic.dhcp.neutron.NeutronDHCPApi._get_port_ip_address',
                 autospec=True)
