@@ -20,7 +20,7 @@ Test class for DRAC boot interface
 
 from unittest import mock
 
-from oslo_utils import importutils
+import sushy
 
 from ironic.common import boot_devices
 from ironic.conductor import task_manager
@@ -30,8 +30,6 @@ from ironic.tests.unit.db import utils as db_utils
 from ironic.tests.unit.drivers.modules.drac import utils as test_utils
 from ironic.tests.unit.objects import utils as obj_utils
 
-sushy = importutils.try_import('sushy')
-
 INFO_DICT = dict(db_utils.get_test_redfish_info(), **test_utils.INFO_DICT)
 
 
@@ -77,7 +75,7 @@ class DracBootTestCase(test_utils.BaseDracTest):
                 task, boot_devices.CDROM, persistent=True)
 
             mock_manager_oem.set_virtual_boot_device.assert_called_once_with(
-                'cd', persistent=True, system=mock_system)
+                sushy.VIRTUAL_MEDIA_CD, persistent=True, system=mock_system)
 
     def test__set_boot_device_cd(self, mock_get_system):
         mock_system = mock_get_system.return_value
@@ -90,7 +88,7 @@ class DracBootTestCase(test_utils.BaseDracTest):
             task.driver.boot._set_boot_device(task, boot_devices.CDROM)
 
             mock_manager_oem.set_virtual_boot_device.assert_called_once_with(
-                'cd', persistent=False, system=mock_system)
+                sushy.VIRTUAL_MEDIA_CD, persistent=False, system=mock_system)
 
     def test__set_boot_device_floppy(self, mock_get_system):
         mock_system = mock_get_system.return_value
@@ -103,7 +101,8 @@ class DracBootTestCase(test_utils.BaseDracTest):
             task.driver.boot._set_boot_device(task, boot_devices.FLOPPY)
 
             mock_manager_oem.set_virtual_boot_device.assert_called_once_with(
-                'floppy', persistent=False, system=mock_system)
+                sushy.VIRTUAL_MEDIA_FLOPPY, persistent=False,
+                system=mock_system)
 
     def test__set_boot_device_disk(self, mock_get_system):
         mock_system = mock_get_system.return_value
