@@ -34,7 +34,10 @@ from ironic.drivers.modules.redfish import utils as redfish_utils
 from ironic.tests.unit.drivers.modules.drac import utils as test_utils
 from ironic.tests.unit.objects import utils as obj_utils
 
-sushy_oem_idrac = importutils.try_import('sushy_oem_idrac')
+try:
+    from sushy.oem import dell as sushy_oem_idrac
+except ModuleNotFoundError:
+    sushy_oem_idrac = importutils.try_import('sushy_oem_idrac')
 
 INFO_DICT = test_utils.INFO_DICT
 
