@@ -65,7 +65,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
                                   get_capabilities_mock):
         ilo_object_mock = get_ilo_object_mock.return_value
         properties = {'memory_mb': '512', 'local_gb': '10',
-                      'cpus': '1', 'cpu_arch': 'x86_64'}
+                      'cpu_arch': 'x86_64'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
         capabilities = {}
         result = {'properties': properties, 'macs': macs}
@@ -81,7 +81,8 @@ class IloInspectTestCase(test_common.BaseIloTest):
                                                        ilo_object_mock)
             get_capabilities_mock.assert_called_once_with(task.node,
                                                           ilo_object_mock)
-            create_port_mock.assert_called_once_with(task, macs)
+            create_port_mock.assert_called_once_with(
+                task, ['aa:aa:aa:aa:aa:aa', 'bb:bb:bb:bb:bb:bb'])
 
     @mock.patch.object(ilo_inspect.LOG, 'warning',
                        spec_set=True, autospec=True)
@@ -102,8 +103,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
                                                 get_capabilities_mock,
                                                 log_mock):
         ilo_object_mock = get_ilo_object_mock.return_value
-        properties = {'memory_mb': '512', 'local_gb': 0,
-                      'cpus': '1', 'cpu_arch': 'x86_64'}
+        properties = {'memory_mb': '512', 'local_gb': 0, 'cpu_arch': 'x86_64'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
         capabilities = {}
         result = {'properties': properties, 'macs': macs}
@@ -117,7 +117,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
             task.node.properties = properties
             task.node.save()
             expected_properties = {'memory_mb': '512', 'local_gb': 10,
-                                   'cpus': '1', 'cpu_arch': 'x86_64'}
+                                   'cpu_arch': 'x86_64'}
             task.driver.inspect.inspect_hardware(task)
             self.assertEqual(expected_properties, task.node.properties)
             power_mock.assert_called_once_with(mock.ANY, task)
@@ -126,7 +126,8 @@ class IloInspectTestCase(test_common.BaseIloTest):
             self.assertTrue(log_mock.called)
             get_capabilities_mock.assert_called_once_with(task.node,
                                                           ilo_object_mock)
-            create_port_mock.assert_called_once_with(task, macs)
+            create_port_mock.assert_called_once_with(
+                task, ['aa:aa:aa:aa:aa:aa', 'bb:bb:bb:bb:bb:bb'])
 
     @mock.patch.object(ilo_inspect.LOG, 'warning',
                        spec_set=True, autospec=True)
@@ -147,8 +148,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
                              get_capabilities_mock,
                              log_mock):
         ilo_object_mock = get_ilo_object_mock.return_value
-        properties = {'memory_mb': '512', 'local_gb': 10,
-                      'cpus': '1', 'cpu_arch': 'x86_64'}
+        properties = {'memory_mb': '512', 'local_gb': 10, 'cpu_arch': 'x86_64'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
         capabilities = {'server_model': 'Gen8'}
         result = {'properties': properties, 'macs': macs}
@@ -158,7 +158,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=False) as task:
             expected_properties = {'memory_mb': '512', 'local_gb': 10,
-                                   'cpus': '1', 'cpu_arch': 'x86_64',
+                                   'cpu_arch': 'x86_64',
                                    'capabilities': 'server_model:Gen8'}
             task.driver.inspect.inspect_hardware(task)
             self.assertEqual(expected_properties, task.node.properties)
@@ -168,7 +168,8 @@ class IloInspectTestCase(test_common.BaseIloTest):
             self.assertTrue(log_mock.called)
             get_capabilities_mock.assert_called_once_with(task.node,
                                                           ilo_object_mock)
-            create_port_mock.assert_called_once_with(task, macs)
+            create_port_mock.assert_called_once_with(
+                task, ['aa:aa:aa:aa:aa:aa', 'bb:bb:bb:bb:bb:bb'])
 
     @mock.patch.object(ilo_inspect.LOG, 'warning',
                        spec_set=True, autospec=True)
@@ -192,8 +193,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
                               get_security_params_mock,
                               log_mock):
         ilo_object_mock = get_ilo_object_mock.return_value
-        properties = {'memory_mb': '512', 'local_gb': 10,
-                      'cpus': '1', 'cpu_arch': 'x86_64'}
+        properties = {'memory_mb': '512', 'local_gb': 10, 'cpu_arch': 'x86_64'}
         macs = {'NIC.LOM.1.1': 'aa:aa:aa:aa:aa:aa'}
         capabilities = {'server_model': 'Gen10'}
         security_params = (
@@ -206,7 +206,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=False) as task:
             expected_properties = {
-                'memory_mb': '512', 'local_gb': 10, 'cpus': '1',
+                'memory_mb': '512', 'local_gb': 10,
                 'cpu_arch': 'x86_64', 'capabilities': 'server_model:Gen10',
                 'security_parameters': {'Password Complexity': 'ok'}}
             task.driver.inspect.inspect_hardware(task)
@@ -217,7 +217,8 @@ class IloInspectTestCase(test_common.BaseIloTest):
             self.assertFalse(log_mock.called)
             get_capabilities_mock.assert_called_once_with(task.node,
                                                           ilo_object_mock)
-            create_port_mock.assert_called_once_with(task, macs)
+            create_port_mock.assert_called_once_with(
+                task, ['aa:aa:aa:aa:aa:aa'])
 
     @mock.patch.object(ilo_inspect, '_get_capabilities', spec_set=True,
                        autospec=True)
@@ -239,7 +240,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
                                             get_capabilities_mock):
         ilo_object_mock = get_ilo_object_mock.return_value
         properties = {'memory_mb': '512', 'local_gb': '10',
-                      'cpus': '1', 'cpu_arch': 'x86_64'}
+                      'cpu_arch': 'x86_64'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
         capabilities = {}
         result = {'properties': properties, 'macs': macs}
@@ -256,7 +257,8 @@ class IloInspectTestCase(test_common.BaseIloTest):
                                                        ilo_object_mock)
             get_capabilities_mock.assert_called_once_with(task.node,
                                                           ilo_object_mock)
-            create_port_mock.assert_called_once_with(task, macs)
+            create_port_mock.assert_called_once_with(
+                task, ['aa:aa:aa:aa:aa:aa', 'bb:bb:bb:bb:bb:bb'])
 
     @mock.patch.object(ilo_inspect, '_get_capabilities', spec_set=True,
                        autospec=True)
@@ -275,7 +277,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
                                                get_capabilities_mock):
         ilo_object_mock = get_ilo_object_mock.return_value
         properties = {'memory_mb': '512', 'local_gb': '10',
-                      'cpus': '1', 'cpu_arch': 'x86_64'}
+                      'cpu_arch': 'x86_64'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
         capability_str = 'sriov_enabled:true'
         capabilities = {'sriov_enabled': 'true'}
@@ -287,7 +289,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
                                   shared=False) as task:
             task.driver.inspect.inspect_hardware(task)
             expected_properties = {'memory_mb': '512', 'local_gb': '10',
-                                   'cpus': '1', 'cpu_arch': 'x86_64',
+                                   'cpu_arch': 'x86_64',
                                    'capabilities': capability_str}
             self.assertEqual(expected_properties, task.node.properties)
             power_mock.assert_called_once_with(mock.ANY, task)
@@ -295,7 +297,8 @@ class IloInspectTestCase(test_common.BaseIloTest):
                                                        ilo_object_mock)
             get_capabilities_mock.assert_called_once_with(task.node,
                                                           ilo_object_mock)
-            create_port_mock.assert_called_once_with(task, macs)
+            create_port_mock.assert_called_once_with(
+                task, ['aa:aa:aa:aa:aa:aa', 'bb:bb:bb:bb:bb:bb'])
 
     @mock.patch.object(ilo_inspect, '_get_capabilities', spec_set=True,
                        autospec=True)
@@ -314,8 +317,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
                                                      get_capabilities_mock):
         ilo_object_mock = get_ilo_object_mock.return_value
         properties = {'memory_mb': '512', 'local_gb': '10',
-                      'cpus': '1', 'cpu_arch': 'x86_64',
-                      'somekey': 'somevalue'}
+                      'cpu_arch': 'x86_64', 'somekey': 'somevalue'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
         result = {'properties': properties, 'macs': macs}
         capabilities = {'sriov_enabled': 'true'}
@@ -333,7 +335,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
             set2 = set(end_capabilities.split(','))
             self.assertEqual(set1, set2)
             expected_properties = {'memory_mb': '512', 'local_gb': '10',
-                                   'cpus': '1', 'cpu_arch': 'x86_64',
+                                   'cpu_arch': 'x86_64',
                                    'capabilities': end_capabilities}
             power_mock.assert_called_once_with(mock.ANY, task)
             self.assertEqual(task.node.properties, expected_properties)
@@ -341,7 +343,8 @@ class IloInspectTestCase(test_common.BaseIloTest):
                                                        ilo_object_mock)
             get_capabilities_mock.assert_called_once_with(task.node,
                                                           ilo_object_mock)
-            create_port_mock.assert_called_once_with(task, macs)
+            create_port_mock.assert_called_once_with(
+                task, ['aa:aa:aa:aa:aa:aa', 'bb:bb:bb:bb:bb:bb'])
 
 
 class TestInspectPrivateMethods(test_common.BaseIloTest):
@@ -349,7 +352,7 @@ class TestInspectPrivateMethods(test_common.BaseIloTest):
     def test__get_essential_properties_ok(self):
         ilo_mock = mock.MagicMock(spec=['get_essential_properties'])
         properties = {'memory_mb': '512', 'local_gb': '10',
-                      'cpus': '1', 'cpu_arch': 'x86_64'}
+                      'cpu_arch': 'x86_64'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
         result = {'properties': properties, 'macs': macs}
         ilo_mock.get_essential_properties.return_value = result
@@ -361,8 +364,7 @@ class TestInspectPrivateMethods(test_common.BaseIloTest):
         ilo_mock = mock.MagicMock(
             spec=['get_additional_capabilities', 'get_essential_properties'])
         # Missing key: cpu_arch
-        properties = {'memory_mb': '512', 'local_gb': '10',
-                      'cpus': '1'}
+        properties = {'memory_mb': '512', 'local_gb': '10'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
         result = {'properties': properties, 'macs': macs}
         ilo_mock.get_essential_properties.return_value = result
@@ -379,8 +381,7 @@ class TestInspectPrivateMethods(test_common.BaseIloTest):
         ilo_mock = mock.MagicMock(
             spec=['get_additional_capabilities', 'get_essential_properties'])
         # Not a dict
-        properties = ['memory_mb', '512', 'local_gb', '10',
-                      'cpus', '1']
+        properties = ['memory_mb', '512', 'local_gb', '10']
         macs = ['aa:aa:aa:aa:aa:aa', 'bb:bb:bb:bb:bb:bb']
         capabilities = ''
         result = {'properties': properties, 'macs': macs}
@@ -393,7 +394,7 @@ class TestInspectPrivateMethods(test_common.BaseIloTest):
     def test__get_essential_properties_fail_mac_invalid_format(self):
         ilo_mock = mock.MagicMock(spec=['get_essential_properties'])
         properties = {'memory_mb': '512', 'local_gb': '10',
-                      'cpus': '1', 'cpu_arch': 'x86_64'}
+                      'cpu_arch': 'x86_64'}
         # Not a dict
         macs = 'aa:aa:aa:aa:aa:aa'
         result = {'properties': properties, 'macs': macs}
@@ -406,7 +407,7 @@ class TestInspectPrivateMethods(test_common.BaseIloTest):
         ilo_mock = mock.MagicMock(
             spec=['get_additional_capabilities', 'get_essential_properties'])
         properties = {'memory_mb': '512', 'local_gb': '10',
-                      'cpus': '1', 'cpu_arch': 'x86_64'}
+                      'cpu_arch': 'x86_64'}
         # Not a dictionary
         macs = None
         result = {'properties': properties, 'macs': macs}
@@ -420,7 +421,7 @@ class TestInspectPrivateMethods(test_common.BaseIloTest):
     def test__get_essential_properties_hardware_port_not_dict(self):
         ilo_mock = mock.MagicMock(spec=['get_essential_properties'])
         properties = {'memory_mb': '512', 'local_gb': '10',
-                      'cpus': '1', 'cpu_arch': 'x86_64'}
+                      'cpu_arch': 'x86_64'}
         # Not a dict
         macs = 'aa:bb:cc:dd:ee:ff'
         result = {'properties': properties, 'macs': macs}
@@ -440,7 +441,7 @@ class TestInspectPrivateMethods(test_common.BaseIloTest):
 
     def test__validate_ok(self):
         properties = {'memory_mb': '512', 'local_gb': '10',
-                      'cpus': '2', 'cpu_arch': 'x86_arch'}
+                      'cpu_arch': 'x86_arch'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa'}
         data = {'properties': properties, 'macs': macs}
         valid_keys = ilo_inspect.IloInspect.ESSENTIAL_PROPERTIES
@@ -448,8 +449,7 @@ class TestInspectPrivateMethods(test_common.BaseIloTest):
         self.assertEqual(sorted(set(properties)), sorted(valid_keys))
 
     def test__validate_essential_keys_fail_missing_key(self):
-        properties = {'memory_mb': '512', 'local_gb': '10',
-                      'cpus': '1'}
+        properties = {'memory_mb': '512', 'local_gb': '10'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa'}
         data = {'properties': properties, 'macs': macs}
         self.assertRaises(exception.HardwareInspectionFailure,
