@@ -23,7 +23,6 @@ from oslo_utils import uuidutils
 from ironic.conductor import task_manager
 from ironic.drivers.modules.irmc import common as irmc_common
 from ironic.drivers.modules.irmc import raid as irmc_raid
-from ironic.drivers.modules import noop
 from ironic.tests.unit.drivers.modules.irmc import test_common
 from ironic.tests.unit.objects import utils as obj_utils
 
@@ -49,8 +48,10 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
                 {
                     'key': 'value'
                 }]}
+        self.node.raid_config = self.raid_config
+        self.node.target_raid_config = self.target_raid_config
 
-    @mock.patch.object(irmc_common, 'get_irmc_report')
+    @mock.patch.object(irmc_common, 'get_irmc_report', autospec=True)
     def test__query_raid_config_fgi_status_without_node(
             self, report_mock):
         mock_manager = mock.Mock()
@@ -60,24 +61,7 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
         raid_object._query_raid_config_fgi_status(mock_manager, None)
         self.assertEqual(0, report_mock.call_count)
 
-    @mock.patch.object(irmc_common, 'get_irmc_report')
-    @mock.patch.object(task_manager, 'acquire', autospec=True)
-    def test__query_raid_config_fgi_status_without_raid_object(
-            self, mock_acquire, report_mock):
-        mock_manager = mock.Mock()
-        raid_config = self.raid_config
-        task = mock.Mock(node=self.node, driver=self.driver)
-        mock_acquire.return_value = mock.MagicMock(
-            __enter__=mock.MagicMock(return_value=task))
-        node_list = [(self.node.uuid, 'irmc', '', raid_config)]
-        mock_manager.iter_nodes.return_value = node_list
-        task.driver.raid = noop.NoRAID()
-        raid_object = irmc_raid.IRMCRAID()
-        raid_object._query_raid_config_fgi_status(mock_manager,
-                                                  self.context)
-        self.assertEqual(0, report_mock.call_count)
-
-    @mock.patch.object(irmc_common, 'get_irmc_report')
+    @mock.patch.object(irmc_common, 'get_irmc_report', autospec=True)
     @mock.patch.object(task_manager, 'acquire', autospec=True)
     def test__query_raid_config_fgi_status_without_input(
             self, mock_acquire, report_mock):
@@ -95,7 +79,7 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
                                                        self.context)
         self.assertEqual(0, report_mock.call_count)
 
-    @mock.patch.object(irmc_common, 'get_irmc_report')
+    @mock.patch.object(irmc_common, 'get_irmc_report', autospec=True)
     @mock.patch.object(task_manager, 'acquire', autospec=True)
     def test__query_raid_config_fgi_status_without_raid_config(
             self, mock_acquire, report_mock):
@@ -110,7 +94,7 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
                                                        self.context)
         self.assertEqual(0, report_mock.call_count)
 
-    @mock.patch.object(irmc_common, 'get_irmc_report')
+    @mock.patch.object(irmc_common, 'get_irmc_report', autospec=True)
     @mock.patch.object(task_manager, 'acquire', autospec=True)
     def test__query_raid_config_fgi_status_without_fgi_status(
             self, mock_acquire, report_mock):
@@ -132,7 +116,7 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
                                                        self.context)
         self.assertEqual(0, report_mock.call_count)
 
-    @mock.patch.object(irmc_common, 'get_irmc_report')
+    @mock.patch.object(irmc_common, 'get_irmc_report', autospec=True)
     @mock.patch.object(task_manager, 'acquire', autospec=True)
     def test__query_raid_config_fgi_status_other_clean_state(
             self, mock_acquire, report_mock):
@@ -150,9 +134,11 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
                                                        self.context)
         self.assertEqual(0, report_mock.call_count)
 
-    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._set_clean_failed')
-    @mock.patch('ironic.drivers.modules.irmc.raid._get_fgi_status')
-    @mock.patch.object(irmc_common, 'get_irmc_report')
+    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._set_clean_failed',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.irmc.raid._get_fgi_status',
+                autospec=True)
+    @mock.patch.object(irmc_common, 'get_irmc_report', autospec=True)
     @mock.patch.object(task_manager, 'acquire', autospec=True)
     def test__query_raid_config_fgi_status_completing_status(
             self, mock_acquire, report_mock, fgi_mock, clean_fail_mock):
@@ -176,9 +162,11 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
         fgi_mock.assert_called_once_with(report_mock.return_value,
                                          self.node.uuid)
 
-    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._set_clean_failed')
-    @mock.patch('ironic.drivers.modules.irmc.raid._get_fgi_status')
-    @mock.patch.object(irmc_common, 'get_irmc_report')
+    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._set_clean_failed',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.irmc.raid._get_fgi_status',
+                autospec=True)
+    @mock.patch.object(irmc_common, 'get_irmc_report', autospec=True)
     @mock.patch.object(task_manager, 'acquire', autospec=True)
     def test__query_raid_config_fgi_status_with_clean_fail(
             self, mock_acquire, report_mock, fgi_mock, clean_fail_mock):
@@ -198,15 +186,19 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
         task.node.save()
         task.driver.raid._query_raid_config_fgi_status(mock_manager,
                                                        self.context)
-        clean_fail_mock.assert_called_once_with(task, fgi_status_dict)
+        clean_fail_mock.assert_called_once_with(mock.ANY, task,
+                                                fgi_status_dict)
         report_mock.assert_called_once_with(task.node)
         fgi_mock.assert_called_once_with(report_mock.return_value,
                                          self.node.uuid)
 
-    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._resume_cleaning')
-    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._set_clean_failed')
-    @mock.patch('ironic.drivers.modules.irmc.raid._get_fgi_status')
-    @mock.patch.object(irmc_common, 'get_irmc_report')
+    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._resume_cleaning',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._set_clean_failed',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.irmc.raid._get_fgi_status',
+                autospec=True)
+    @mock.patch.object(irmc_common, 'get_irmc_report', autospec=True)
     @mock.patch.object(task_manager, 'acquire', autospec=True)
     def test__query_raid_config_fgi_status_with_complete_cleaning(
             self, mock_acquire, report_mock, fgi_mock, clean_fail_mock,
@@ -229,12 +221,15 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
         report_mock.assert_called_once_with(task.node)
         fgi_mock.assert_called_once_with(report_mock.return_value,
                                          self.node.uuid)
-        clean_mock.assert_called_once_with(task)
+        clean_mock.assert_called_once_with(mock.ANY, task)
 
-    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._resume_cleaning')
-    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._set_clean_failed')
-    @mock.patch('ironic.drivers.modules.irmc.raid._get_fgi_status')
-    @mock.patch.object(irmc_common, 'get_irmc_report')
+    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._resume_cleaning',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._set_clean_failed',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.irmc.raid._get_fgi_status',
+                autospec=True)
+    @mock.patch.object(irmc_common, 'get_irmc_report', autospec=True)
     @mock.patch.object(task_manager, 'acquire', autospec=True)
     def test__query_raid_config_fgi_status_with_two_nodes_without_raid_config(
             self, mock_acquire, report_mock, fgi_mock, clean_fail_mock,
@@ -259,12 +254,15 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
         report_mock.assert_called_once_with(task.node)
         fgi_mock.assert_called_once_with(report_mock.return_value,
                                          self.node.uuid)
-        clean_mock.assert_called_once_with(task)
+        clean_mock.assert_called_once_with(mock.ANY, task)
 
-    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._resume_cleaning')
-    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._set_clean_failed')
-    @mock.patch('ironic.drivers.modules.irmc.raid._get_fgi_status')
-    @mock.patch.object(irmc_common, 'get_irmc_report')
+    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._resume_cleaning',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._set_clean_failed',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.irmc.raid._get_fgi_status',
+                autospec=True)
+    @mock.patch.object(irmc_common, 'get_irmc_report', autospec=True)
     @mock.patch.object(task_manager, 'acquire', autospec=True)
     def test__query_raid_config_fgi_status_with_two_nodes_with_fgi_status_none(
             self, mock_acquire, report_mock, fgi_mock, clean_fail_mock,
@@ -272,6 +270,7 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
         mock_manager = mock.Mock()
         raid_config = self.raid_config
         raid_config_2 = self.raid_config.copy()
+        self.node_2.raid_config = raid_config_2
         fgi_status_dict = {}
         fgi_mock.side_effect = [{}, {'0': 'Idle', '1': 'Idle'}]
         node_list = [(self.node_2.uuid, 'fake-hardware', '', raid_config_2),
@@ -291,5 +290,44 @@ class iRMCPeriodicTaskTestCase(test_common.BaseIRMCTest):
                                              self.node_2.uuid),
                                    mock.call(report_mock.return_value,
                                              self.node_2.uuid)])
-        clean_fail_mock.assert_called_once_with(task, fgi_status_dict)
-        clean_mock.assert_called_once_with(task)
+        clean_fail_mock.assert_called_once_with(mock.ANY,
+                                                task, fgi_status_dict)
+        clean_mock.assert_called_once_with(mock.ANY, task)
+
+    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._resume_cleaning',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.irmc.raid.IRMCRAID._set_clean_failed',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.irmc.raid._get_fgi_status',
+                autospec=True)
+    @mock.patch.object(irmc_common, 'get_irmc_report', autospec=True)
+    @mock.patch.object(task_manager, 'acquire', autospec=True)
+    def test__query_raid_config_fgi_status_avoid_repeatedly_resume_cleaning(
+            self, mock_acquire, report_mock, fgi_mock, clean_fail_mock,
+            clean_mock):
+        mock_manager = mock.Mock()
+        raid_config = self.raid_config
+        fgi_mock.return_value = {'0': 'Idle', '1': 'Idle'}
+        task = mock.Mock(node=self.node, driver=self.driver)
+        mock_acquire.return_value = mock.MagicMock(
+            __enter__=mock.MagicMock(return_value=task))
+        task.node.raid_config = raid_config
+        node_list = [(self.node.uuid, 'irmc', '', raid_config)]
+        mock_manager.iter_nodes.return_value = node_list
+        # Set provision state value
+        task.node.provision_state = 'clean wait'
+        task.node.save()
+        task.driver.raid._query_raid_config_fgi_status(mock_manager,
+                                                       self.context)
+        raid_config = task.node.raid_config
+        node_list = [(self.node.uuid, 'irmc', '', raid_config)]
+        mock_manager.iter_nodes.return_value = node_list
+        task.node.provision_state = 'clean wait'
+        task.node.save()
+        task.driver.raid._query_raid_config_fgi_status(mock_manager,
+                                                       self.context)
+        self.assertEqual(0, clean_fail_mock.call_count)
+        report_mock.assert_called_once_with(task.node)
+        fgi_mock.assert_called_once_with(report_mock.return_value,
+                                         self.node.uuid)
+        clean_mock.assert_called_once_with(mock.ANY, task)
