@@ -52,8 +52,6 @@ class IRMCPowerInternalMethodsTestCase(test_common.BaseIRMCTest):
         self.assertFalse(irmc_power._is_expected_power_state(
             target_state, boot_status_value))
 
-    @mock.patch('oslo_utils.eventletutils.EventletEvent.wait',
-                lambda *args, **kwargs: None)
     @mock.patch('ironic.drivers.modules.irmc.power.snmp.SNMPClient',
                 spec_set=True, autospec=True)
     def test__wait_power_state_soft_power_off(self, snmpclient_mock):
@@ -72,8 +70,6 @@ class IRMCPowerInternalMethodsTestCase(test_common.BaseIRMCTest):
             self.assertEqual(states.POWER_OFF, task.node.power_state)
             self.assertEqual(states.NOSTATE, task.node.target_power_state)
 
-    @mock.patch('oslo_utils.eventletutils.EventletEvent.wait',
-                lambda *args, **kwargs: None)
     @mock.patch('ironic.drivers.modules.irmc.power.snmp.SNMPClient',
                 spec_set=True, autospec=True)
     def test__wait_power_state_soft_reboot(self, snmpclient_mock):
@@ -92,8 +88,6 @@ class IRMCPowerInternalMethodsTestCase(test_common.BaseIRMCTest):
             self.assertEqual(states.POWER_ON, task.node.power_state)
             self.assertEqual(states.NOSTATE, task.node.target_power_state)
 
-    @mock.patch('oslo_utils.eventletutils.EventletEvent.wait',
-                lambda *args, **kwargs: None)
     @mock.patch('ironic.drivers.modules.irmc.power.snmp.SNMPClient',
                 spec_set=True, autospec=True)
     def test__wait_power_state_timeout(self, snmpclient_mock):
