@@ -12,7 +12,7 @@
 
 from unittest import mock
 
-from neutronclient.common import exceptions as neutron_exceptions
+from openstack.connection import exceptions as openstack_exc
 from oslo_config import cfg
 from oslo_utils import uuidutils
 
@@ -78,7 +78,7 @@ class TestFlatInterface(db_base.DbTestCase):
             self.interface.validate(task)
             validate_mock.assert_called_once_with(
                 CONF.neutron.cleaning_network,
-                'cleaning network', context=task.context)
+                'cleaning_network', context=task.context)
 
     @mock.patch.object(neutron, 'validate_network', autospec=True)
     def test_validate_from_node(self, validate_mock):
@@ -91,7 +91,7 @@ class TestFlatInterface(db_base.DbTestCase):
             self.interface.validate(task)
         validate_mock.assert_called_once_with(
             cleaning_network_uuid,
-            'cleaning network', context=task.context)
+            'cleaning_network', context=task.context)
 
     @mock.patch.object(neutron, 'validate_network',
                        side_effect=lambda n, t, context=None: n, autospec=True)
@@ -107,7 +107,7 @@ class TestFlatInterface(db_base.DbTestCase):
             add_mock.assert_called_once_with(
                 task, CONF.neutron.cleaning_network)
             validate_mock.assert_called_once_with(
-                CONF.neutron.cleaning_network, 'cleaning network',
+                CONF.neutron.cleaning_network, 'cleaning_network',
                 context=task.context)
         self.port.refresh()
         self.assertEqual('vif-port-id',
@@ -134,7 +134,7 @@ class TestFlatInterface(db_base.DbTestCase):
                 add_mock.assert_called_with(task, cleaning_network_uuid)
                 validate_mock.assert_called_with(
                     cleaning_network_uuid,
-                    'cleaning network', context=task.context)
+                    'cleaning_network', context=task.context)
         self.port.refresh()
         self.assertEqual('vif-port-id',
                          self.port.internal_info['cleaning_vif_port_id'])
@@ -149,7 +149,7 @@ class TestFlatInterface(db_base.DbTestCase):
                 task, CONF.neutron.cleaning_network)
             validate_mock.assert_called_once_with(
                 CONF.neutron.cleaning_network,
-                'cleaning network', context=task.context)
+                'cleaning_network', context=task.context)
         self.port.refresh()
         self.assertNotIn('cleaning_vif_port_id', self.port.internal_info)
 
@@ -168,19 +168,20 @@ class TestFlatInterface(db_base.DbTestCase):
             remove_mock.assert_called_once_with(task, cleaning_network_uuid)
             validate_mock.assert_called_once_with(
                 cleaning_network_uuid,
-                'cleaning network', context=task.context)
+                'cleaning_network', context=task.context)
         self.port.refresh()
         self.assertNotIn('cleaning_vif_port_id', self.port.internal_info)
 
     @mock.patch.object(neutron, 'update_neutron_port', autospec=True)
     def test__bind_flat_ports_set_binding_host_id(self, update_mock):
-        extra = {'vif_port_id': 'foo'}
+        internal_info = {'tenant_vif_port_id': 'foo'}
         utils.create_test_port(self.context, node_id=self.node.id,
-                               address='52:54:00:cf:2d:33', extra=extra,
+                               address='52:54:00:cf:2d:33',
+                               internal_info=internal_info,
                                uuid=uuidutils.generate_uuid())
-        exp_body = {'port': {'binding:host_id': self.node.uuid,
-                             'binding:vnic_type': neutron.VNIC_BAREMETAL,
-                             'mac_address': '52:54:00:cf:2d:33'}}
+        exp_body = {'binding:host_id': self.node.uuid,
+                    'binding:vnic_type': neutron.VNIC_BAREMETAL,
+                    'mac_address': '52:54:00:cf:2d:33'}
         with task_manager.acquire(self.context, self.node.id) as task:
             self.interface._bind_flat_ports(task)
         update_mock.assert_called_once_with(self.context, 'foo', exp_body)
@@ -193,13 +194,14 @@ class TestFlatInterface(db_base.DbTestCase):
             uuid=uuidutils.generate_uuid())
         utils.create_test_port(
             self.context, node_id=self.node.id, address='52:54:00:cf:2d:33',
-            extra={'vif_port_id': 'bar'}, uuid=uuidutils.generate_uuid())
-        exp_body1 = {'port': {'binding:host_id': self.node.uuid,
-                              'binding:vnic_type': neutron.VNIC_BAREMETAL,
-                              'mac_address': '52:54:00:cf:2d:33'}}
-        exp_body2 = {'port': {'binding:host_id': self.node.uuid,
-                              'binding:vnic_type': neutron.VNIC_BAREMETAL,
-                              'mac_address': '52:54:00:cf:2d:31'}}
+            internal_info={'tenant_vif_port_id': 'bar'},
+            uuid=uuidutils.generate_uuid())
+        exp_body1 = {'binding:host_id': self.node.uuid,
+                     'binding:vnic_type': neutron.VNIC_BAREMETAL,
+                     'mac_address': '52:54:00:cf:2d:33'}
+        exp_body2 = {'binding:host_id': self.node.uuid,
+                     'binding:vnic_type': neutron.VNIC_BAREMETAL,
+                     'mac_address': '52:54:00:cf:2d:31'}
         with task_manager.acquire(self.context, self.node.id) as task:
             self.interface._bind_flat_ports(task)
         update_mock.assert_has_calls([
@@ -208,9 +210,10 @@ class TestFlatInterface(db_base.DbTestCase):
 
     @mock.patch.object(neutron, 'unbind_neutron_port', autospec=True)
     def test__unbind_flat_ports(self, unbind_neutron_port_mock):
-        extra = {'vif_port_id': 'foo'}
+        internal_info = {'tenant_vif_port_id': 'foo'}
         utils.create_test_port(self.context, node_id=self.node.id,
-                               address='52:54:00:cf:2d:33', extra=extra,
+                               address='52:54:00:cf:2d:33',
+                               internal_info=internal_info,
                                uuid=uuidutils.generate_uuid())
         with task_manager.acquire(self.context, self.node.id) as task:
             self.interface._unbind_flat_ports(task)
@@ -223,9 +226,10 @@ class TestFlatInterface(db_base.DbTestCase):
         utils.create_test_portgroup(self.context, node_id=self.node.id,
                                     internal_info=internal_info,
                                     uuid=uuidutils.generate_uuid())
-        extra = {'vif_port_id': 'bar'}
+        internal_info = {'tenant_vif_port_id': 'bar'}
         utils.create_test_port(self.context, node_id=self.node.id,
-                               address='52:54:00:cf:2d:33', extra=extra,
+                               address='52:54:00:cf:2d:33',
+                               internal_info=internal_info,
                                uuid=uuidutils.generate_uuid())
         with task_manager.acquire(self.context, self.node.id) as task:
             self.interface._unbind_flat_ports(task)
@@ -235,10 +239,11 @@ class TestFlatInterface(db_base.DbTestCase):
 
     @mock.patch.object(neutron, 'update_neutron_port', autospec=True)
     def test__bind_flat_ports_set_binding_host_id_raise(self, update_mock):
-        update_mock.side_effect = (neutron_exceptions.ConnectionFailed())
-        extra = {'vif_port_id': 'foo'}
+        update_mock.side_effect = openstack_exc.OpenStackCloudException()
+        internal_info = {'tenant_vif_port_id': 'foo'}
         utils.create_test_port(self.context, node_id=self.node.id,
-                               address='52:54:00:cf:2d:33', extra=extra,
+                               address='52:54:00:cf:2d:33',
+                               internal_info=internal_info,
                                uuid=uuidutils.generate_uuid())
         with task_manager.acquire(self.context, self.node.id) as task:
             self.assertRaises(exception.NetworkError,
@@ -286,7 +291,7 @@ class TestFlatInterface(db_base.DbTestCase):
             add_mock.assert_called_once_with(
                 task, CONF.neutron.inspection_network)
             validate_mock.assert_called_once_with(
-                CONF.neutron.inspection_network, 'inspection network',
+                CONF.neutron.inspection_network, 'inspection_network',
                 context=task.context)
         self.port.refresh()
         self.assertEqual('vif-port-id',
@@ -314,7 +319,7 @@ class TestFlatInterface(db_base.DbTestCase):
                 add_mock.assert_called_with(task, inspection_network_uuid)
                 validate_mock.assert_called_with(
                     inspection_network_uuid,
-                    'inspection network', context=task.context)
+                    'inspection_network', context=task.context)
         self.port.refresh()
         self.assertEqual('vif-port-id',
                          self.port.internal_info['inspection_vif_port_id'])
@@ -330,7 +335,7 @@ class TestFlatInterface(db_base.DbTestCase):
         with task_manager.acquire(self.context, self.node.id) as task:
             self.interface.validate_inspection(task)
             validate_mock.assert_called_once_with(
-                inspection_network_uuid, 'inspection network',
+                inspection_network_uuid, 'inspection_network',
                 context=task.context),
 
     def test_validate_inspection_exc(self):
@@ -347,3 +352,4 @@ class TestFlatInterface(db_base.DbTestCase):
             network_data = self.interface.get_node_network_data(task)
 
         self.assertEqual({}, network_data)
+        self.assertIn('metadata', self.interface.capabilities)
