@@ -62,8 +62,6 @@ def _mock_volume(identity, raid_type=None,
     return volume
 
 
-@mock.patch('oslo_utils.eventletutils.EventletEvent.wait',
-            lambda *args, **kwargs: None)
 @mock.patch.object(redfish_utils, 'get_system', autospec=True)
 class RedfishRAIDTestCase(db_base.DbTestCase):
 
@@ -233,8 +231,10 @@ class RedfishRAIDTestCase(db_base.DbTestCase):
             self.mock_storage]
         self.node.target_raid_config = target_raid_config
         self.node.save()
+        mock_sdii = mock.Mock()
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
+            task.node.set_driver_internal_info = mock_sdii
             task.driver.raid.create_configuration(task)
             pre = '/redfish/v1/Systems/1/Storage/1/Drives/'
             expected_payload = {
@@ -253,6 +253,7 @@ class RedfishRAIDTestCase(db_base.DbTestCase):
             )
             # Async operation, raid_config shouldn't be updated yet
             self.assertEqual({}, task.node.raid_config)
+        self.assertEqual(2, mock_sdii.call_count)
 
     @mock.patch.object(redfish_boot.RedfishVirtualMediaBoot, 'prepare_ramdisk',
                        spec_set=True, autospec=True)
@@ -587,8 +588,10 @@ class RedfishRAIDTestCase(db_base.DbTestCase):
             self.mock_storage]
         self.node.target_raid_config = target_raid_config
         self.node.save()
+        sdii_mock = mock.Mock()
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
+            task.node.set_driver_internal_info = sdii_mock
             task.driver.raid.create_configuration(task)
             pre = '/redfish/v1/Systems/1/Storage/1/Drives/'
             expected_payload = {
@@ -607,6 +610,11 @@ class RedfishRAIDTestCase(db_base.DbTestCase):
             )
             # Async operation, raid_config shouldn't be updated yet
             self.assertEqual({}, task.node.raid_config)
+        sdii_mock.assert_has_calls([
+            mock.call('raid_configs', {'operation': 'create',
+                                       'pending': {},
+                                       'task_monitor_uri': mock.ANY}),
+            mock.call('agent_start_attempted', True)])
 
     @mock.patch.object(redfish_boot.RedfishVirtualMediaBoot, 'prepare_ramdisk',
                        spec_set=True, autospec=True)
@@ -1137,7 +1145,9 @@ class RedfishRAIDTestCase(db_base.DbTestCase):
         nonraid_controller = mock.Mock()
         nonraid_controller.raid_types = []
         nonraid_storage = mock.MagicMock()
-        nonraid_storage.storage_controllers = [nonraid_controller]
+        nonraid_storage.controllers = mock.MagicMock()
+        nonraid_storage.controllers.get_members.return_value = [
+            nonraid_controller]
         nonraid_storage.drives = [_mock_drive(
             identity='Drive1', block_size_bytes=512,
             capacity_bytes=899527000000,
@@ -1162,6 +1172,7 @@ class RedfishRAIDTestCase(db_base.DbTestCase):
         nonraid_controller = mock.Mock()
         nonraid_controller.raid_types = []
         nonraid_storage = mock.MagicMock()
+        nonraid_storage.controllers = None
         nonraid_storage.storage_controllers = [nonraid_controller]
         nonraid_storage.drives = mock.Mock()
 
@@ -1176,6 +1187,73 @@ class RedfishRAIDTestCase(db_base.DbTestCase):
             self.assertEqual(storage, self.mock_storage)
             nonraid_storage.drives.assert_not_called()
 
+    def test__get_controller(self, mock_get_system):
+        nonraid_controller = mock.Mock()
+        nonraid_controller.raid_types = []
+        nonraid_storage = mock.MagicMock()
+        nonraid_storage.get_members.return_value = [nonraid_controller]
+        nonraid_storage.controllers = mock.MagicMock()
+        nonraid_storage.controllers.get_members.return_value = [
+            nonraid_controller]
+        nonraid_storage.drives = [_mock_drive(
+            identity='Drive1', block_size_bytes=512,
+            capacity_bytes=899527000000,
+            media_type='HDD', name='Drive', protocol='SAS')]
+
+        mock_get_system.return_value.storage.get_members.return_value = [
+            nonraid_storage, self.mock_storage]
+
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            storage = redfish_raid._get_storage_controller(
+                task.node, mock_get_system.return_value, ['32ADF365C6C1B7BD'])
+
+            self.assertEqual(storage, self.mock_storage)
+
+    def test__get_first_controller_controllers(self, mock_get_system):
+        controller1 = mock.Mock(name="controller")
+        controller2 = mock.Mock(name="storage_controller")
+
+        storage = mock.MagicMock()
+        storage.get_members.return_value = [controller1]
+
+        storage.storage_controllers = mock.MagicMock()
+        storage.controllers = mock.MagicMock()
+
+        storage.controllers.get_members.return_value = [controller1]
+        storage.storage_controllers.return_value = [controller2]
+
+        result = redfish_utils.get_first_controller(storage)
+        self.assertEqual(result, controller1)
+
+    def test__get_first_controller_storage_controllers(self, mock_get_system):
+        storage = mock.Mock()
+        controller_mock = mock.Mock()
+        storage.storage_controllers = [controller_mock]
+        type(storage).controllers = mock.PropertyMock(
+            side_effect=sushy.exceptions.MissingAttributeError)
+
+        result = redfish_utils.get_first_controller(storage)
+        self.assertEqual(result, controller_mock)
+
+    def test__get_controller_no_controllers(self, mock_get_system):
+        storage = mock.Mock()
+        storage.get_members.return_value = None
+        storage.controllers.return_value = None
+        storage.controllers.get_members.return_value = None
+        storage.storage_controllers.return_value = None
+
+        result = redfish_utils.get_first_controller(storage)
+        self.assertIsNone(result)
+
+    def test__get_first_controller_empty(self, mock_get_system):
+        storage = mock.Mock()
+        storage.controllers = mock.Mock()
+        storage.controllers.get_members.return_value = []
+
+        result = redfish_utils.get_first_controller(storage)
+        self.assertIsNone(result)
+
     @mock.patch.object(redfish_utils, 'get_task_monitor', autospec=True)
     @mock.patch.object(redfish_raid.LOG, 'info', autospec=True)
     def test__raid_config_in_progress_success(
