@@ -18,14 +18,18 @@ import os
 import tempfile
 from unittest import mock
 
+from oslo_config import cfg
 from oslo_utils import uuidutils
 
+from ironic.common import image_service
 from ironic.common import images
 from ironic.common import states
 from ironic.common import utils
 from ironic.conductor import task_manager
 from ironic.drivers.modules import deploy_utils
+from ironic.drivers.modules import image_cache
 from ironic.drivers.modules import image_utils
+from ironic.tests import base
 from ironic.tests.unit.db import base as db_base
 from ironic.tests.unit.db import utils as db_utils
 from ironic.tests.unit.objects import utils as obj_utils
@@ -35,6 +39,47 @@ INFO_DICT = db_utils.get_test_redfish_info()
 INFO_DICT_ILO = db_utils.get_test_ilo_info()
 
 
+@mock.patch.object(image_service, 'get_image_service', autospec=True)
+@mock.patch.object(image_cache.ImageCache, 'clean_up', autospec=True)
+class ISOCacheTestCase(base.TestCase):
+
+    def setUp(self):
+        super().setUp()
+        self.master_dir = tempfile.mkdtemp()
+        cfg.CONF.set_override('iso_master_path', self.master_dir,
+                              group='deploy')
+        self.cache = image_utils.ISOImageCache()
+        self.dest_dir = tempfile.mkdtemp()
+        self.dest_path = os.path.join(self.dest_dir, 'dest')
+        self.uuid = uuidutils.generate_uuid()
+        self.master_path = ''.join([os.path.join(self.master_dir, self.uuid),
+                                    '.converted'])
+        self.img_info = {}
+
+    @mock.patch.object(image_cache.ImageCache, '_download_image',
+                       autospec=True)
+    @mock.patch.object(image_cache, '_fetch', autospec=True)
+    def test_fetch_image_iso(self, mock_fetch, mock_download, mock_clean_up,
+                             mock_image_service):
+        self.cache.master_dir = None
+        self.cache.fetch_image(self.uuid, self.dest_path)
+        mock_fetch.assert_called_once_with(mock.ANY, self.uuid, self.dest_path,
+                                           False, mock.ANY, mock.ANY, mock.ANY,
+                                           disable_validation=True,
+                                           image_auth_data=None)
+
+    @mock.patch.object(os, 'link', autospec=True)
+    @mock.patch.object(image_cache, '_fetch', autospec=True)
+    def test__download_image_iso(self, mock_fetch, mock_link, mock_clean_up,
+                                 mock_image_service):
+        self.cache._download_image(self.uuid, self.master_path, self.dest_path,
+                                   self.img_info)
+        mock_fetch.assert_called_once_with(mock.ANY, self.uuid, mock.ANY,
+                                           False, mock.ANY, mock.ANY, mock.ANY,
+                                           disable_validation=True,
+                                           image_auth_data=None)
+
+
 class RedfishImageHandlerTestCase(db_base.DbTestCase):
 
     def setUp(self):
@@ -122,7 +167,7 @@ class RedfishImageUtilsTestCase(db_base.DbTestCase):
                                   shared=True) as task:
             image_utils.cleanup_floppy_image(task)
 
-            object_name = 'image-%s' % task.node.uuid
+            object_name = 'image-%s.img' % task.node.uuid
 
             mock_unpublish.assert_called_once_with(mock.ANY, object_name)
 
@@ -139,13 +184,13 @@ class RedfishImageUtilsTestCase(db_base.DbTestCase):
 
             url = image_utils.prepare_floppy_image(task)
 
-            object_name = 'image-%s' % task.node.uuid
+            object_name = 'image-%s.img' % task.node.uuid
 
             mock_publish_image.assert_called_once_with(mock.ANY, mock.ANY,
                                                        object_name, None)
 
             mock_create_vfat_image.assert_called_once_with(
-                mock.ANY, parameters=None)
+                mock.ANY, fs_size_kib=1440, parameters=None)
 
             self.assertEqual(expected_url, url)
 
@@ -163,13 +208,14 @@ class RedfishImageUtilsTestCase(db_base.DbTestCase):
 
             url = image_utils.prepare_floppy_image(task)
 
-            object_name = 'image-%s' % task.node.uuid
+            object_name = 'image-%s.img' % task.node.uuid
 
             mock_publish_image.assert_called_once_with(mock.ANY, mock.ANY,
                                                        object_name, None)
 
             mock_create_vfat_image.assert_called_once_with(
-                mock.ANY, parameters={"ipa-api-url": "http://callback"})
+                mock.ANY, fs_size_kib=1440,
+                parameters={"ipa-api-url": "http://callback"})
 
             self.assertEqual(expected_url, url)
 
@@ -189,13 +235,14 @@ class RedfishImageUtilsTestCase(db_base.DbTestCase):
 
             url = image_utils.prepare_floppy_image(task)
 
-            object_name = 'image-%s' % task.node.uuid
+            object_name = 'image-%s.img' % task.node.uuid
 
             mock_publish_image.assert_called_once_with(mock.ANY, mock.ANY,
                                                        object_name, None)
 
             mock_create_vfat_image.assert_called_once_with(
-                mock.ANY, parameters={"ipa-api-url": "http://callback"})
+                mock.ANY, fs_size_kib=1440,
+                parameters={"ipa-api-url": "http://callback"})
 
             self.assertEqual(expected_url, url)
 
@@ -218,13 +265,14 @@ class RedfishImageUtilsTestCase(db_base.DbTestCase):
 
             url = image_utils.prepare_floppy_image(task)
 
-            object_name = 'image-%s' % task.node.uuid
+            object_name = 'image-%s.img' % task.node.uuid
 
             mock_publish_image.assert_called_once_with(
                 mock.ANY, mock.ANY, object_name, override_url)
 
             mock_create_vfat_image.assert_called_once_with(
-                mock.ANY, parameters={"ipa-api-url": "http://callback"})
+                mock.ANY, fs_size_kib=1440,
+                parameters={"ipa-api-url": "http://callback"})
 
             self.assertEqual(expected_url, url)
 
@@ -800,6 +848,29 @@ class RedfishImageUtilsTestCase(db_base.DbTestCase):
                 task, 'kernel', 'ramdisk', 'bootloader', params={},
                 inject_files={}, base_iso=None)
 
+    @mock.patch.object(image_utils, '_prepare_iso_image', autospec=True)
+    def test_prepare_deploy_iso_bootloader_by_arch(self,
+                                                   mock__prepare_iso_image):
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+
+            self.config(bootloader_by_arch={'x86_64': 'bootx64.efi'},
+                        group='conductor')
+
+            d_info = {
+                'deploy_kernel': 'kernel',
+                'deploy_ramdisk': 'ramdisk',
+            }
+            task.node.driver_info.update(d_info)
+
+            task.node.instance_info.update(deploy_boot_mode='uefi')
+
+            image_utils.prepare_deploy_iso(task, {}, 'deploy', d_info)
+
+            mock__prepare_iso_image.assert_called_once_with(
+                task, 'kernel', 'ramdisk', 'bootx64.efi', params={},
+                inject_files={}, base_iso=None)
+
     @mock.patch.object(image_utils, '_prepare_iso_image', autospec=True)
     def test_prepare_deploy_iso_existing_iso(self, mock__prepare_iso_image):
         with task_manager.acquire(self.context, self.node.uuid,
