@@ -45,6 +45,41 @@ class SNMPClientTestCase(base.TestCase):
         self.oid = (1, 3, 6, 1, 1, 1, 0)
         self.value = 'value'
 
+    @mock.patch.object(pysnmp, 'SnmpEngine', autospec=True)
+    def test__get_client(self, mock_snmpengine):
+        driver_info = db_utils.get_test_snmp_info(
+            snmp_address=self.address,
+            snmp_port=self.port,
+            snmp_user='test-user',
+            snmp_auth_protocol='sha',
+            snmp_auth_key='test-auth-key',
+            snmp_priv_protocol='aes',
+            snmp_priv_key='test-priv-key',
+            snmp_context_engine_id='test-engine-id',
+            snmp_context_name='test-context-name',
+            snmp_version='3')
+        node = obj_utils.get_test_node(
+            self.context,
+            driver_info=driver_info)
+        info = snmp._parse_driver_info(node)
+
+        client = snmp._get_client(info)
+
+        mock_snmpengine.assert_called_once_with()
+        self.assertEqual(self.address, client.address)
+        self.assertEqual(int(self.port), client.port)
+        self.assertEqual(snmp.SNMP_V3, client.version)
+        self.assertNotIn('read_community', client.__dict__)
+        self.assertNotIn('write_community', client.__dict__)
+        self.assertEqual('test-user', client.user)
+        self.assertEqual(pysnmp.usmHMACSHAAuthProtocol, client.auth_proto)
+        self.assertEqual('test-auth-key', client.auth_key)
+        self.assertEqual(pysnmp.usmAesCfb128Protocol, client.priv_proto)
+        self.assertEqual('test-priv-key', client.priv_key)
+        self.assertEqual('test-engine-id', client.context_engine_id)
+        self.assertEqual('test-context-name', client.context_name)
+        self.assertEqual(mock_snmpengine.return_value, client.snmp_engine)
+
     @mock.patch.object(pysnmp, 'SnmpEngine', autospec=True)
     def test___init__(self, mock_snmpengine):
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V1)
@@ -781,7 +816,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_called_once_with(driver._snmp_oid())
         self.assertEqual(states.POWER_OFF, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
+    @mock.patch.object(time, 'sleep', autospec=True)
     def test_power_on_delay(self, mock_sleep, mock_get_client):
         # Ensure driver waits for the state to change following a power on
         mock_client = mock_get_client.return_value
@@ -795,7 +830,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_ON, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
+    @mock.patch.object(time, 'sleep', autospec=True)
     def test_power_off_delay(self, mock_sleep, mock_get_client):
         # Ensure driver waits for the state to change following a power off
         mock_client = mock_get_client.return_value
@@ -803,14 +838,14 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.side_effect = [driver.value_power_on,
                                        driver.value_power_off]
         pstate = driver.power_off()
+        self.assertTrue(mock_sleep.called)
         mock_client.set.assert_called_once_with(driver._snmp_oid(),
                                                 driver.value_power_off)
         calls = [mock.call(driver._snmp_oid())] * 2
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_OFF, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
-    def test_power_on_invalid_state(self, mock_sleep, mock_get_client):
+    def test_power_on_invalid_state(self, mock_get_client):
         # Ensure driver retries when querying unexpected states following a
         # power on
         mock_client = mock_get_client.return_value
@@ -824,8 +859,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.ERROR, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
-    def test_power_off_invalid_state(self, mock_sleep, mock_get_client):
+    def test_power_off_invalid_state(self, mock_get_client):
         # Ensure driver retries when querying unexpected states following a
         # power off
         mock_client = mock_get_client.return_value
@@ -885,8 +919,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
                                                 driver.value_power_off)
         mock_client.get.assert_called_once_with(driver._snmp_oid())
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
-    def test_power_on_timeout(self, mock_sleep, mock_get_client):
+    def test_power_on_timeout(self, mock_get_client):
         # Ensure that a power on consistency poll timeout causes an error
         mock_client = mock_get_client.return_value
         driver = snmp._get_driver(self.node)
@@ -899,11 +932,10 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.ERROR, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
-    def test_power_off_timeout(self, mock_sleep, mock_get_client):
+    def test_power_off_timeout(self, mock_get_client):
         # Ensure that a power off consistency poll timeout causes an error
         mock_client = mock_get_client.return_value
-        CONF.set_override('power_timeout', 5, 'snmp')
+        CONF.set_override('power_timeout', 1, 'snmp')
         driver = snmp._get_driver(self.node)
         mock_client.get.return_value = driver.value_power_on
         pstate = driver.power_off()
@@ -928,8 +960,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_ON, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
-    def test_power_reset_off_delay(self, mock_sleep, mock_get_client):
+    def test_power_reset_off_delay(self, mock_get_client):
         # Ensure driver waits for the power off state change following a power
         # reset
         mock_client = mock_get_client.return_value
@@ -945,7 +976,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_ON, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
+    @mock.patch.object(time, 'sleep', autospec=True)
     def test_power_reset_on_delay(self, mock_sleep, mock_get_client):
         # Ensure driver waits for the power on state change following a power
         # reset
@@ -955,6 +986,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
                                        driver.value_power_off,
                                        driver.value_power_on]
         pstate = driver.power_reset()
+        self.assertTrue(mock_sleep.called)
         calls = [mock.call(driver._snmp_oid(), driver.value_power_off),
                  mock.call(driver._snmp_oid(), driver.value_power_on)]
         mock_client.set.assert_has_calls(calls)
@@ -962,7 +994,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_ON, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
+    @mock.patch.object(time, 'sleep', autospec=True)
     def test_power_reset_off_delay_on_delay(self, mock_sleep, mock_get_client):
         # Ensure driver waits for both state changes following a power reset
         mock_client = mock_get_client.return_value
@@ -972,6 +1004,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
                                        driver.value_power_off,
                                        driver.value_power_on]
         pstate = driver.power_reset()
+        self.assertTrue(mock_sleep.called)
         calls = [mock.call(driver._snmp_oid(), driver.value_power_off),
                  mock.call(driver._snmp_oid(), driver.value_power_on)]
         mock_client.set.assert_has_calls(calls)
@@ -979,8 +1012,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.POWER_ON, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
-    def test_power_reset_off_invalid_state(self, mock_sleep, mock_get_client):
+    def test_power_reset_off_invalid_state(self, mock_get_client):
         # Ensure driver retries when querying unexpected states following a
         # power off during a reset
         mock_client = mock_get_client.return_value
@@ -994,8 +1026,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.ERROR, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
-    def test_power_reset_on_invalid_state(self, mock_sleep, mock_get_client):
+    def test_power_reset_on_invalid_state(self, mock_get_client):
         # Ensure driver retries when querying unexpected states following a
         # power on during a reset
         mock_client = mock_get_client.return_value
@@ -1011,8 +1042,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.ERROR, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
-    def test_power_reset_off_timeout(self, mock_sleep, mock_get_client):
+    def test_power_reset_off_timeout(self, mock_get_client):
         # Ensure that a power off consistency poll timeout during a reset
         # causes an error
         mock_client = mock_get_client.return_value
@@ -1026,8 +1056,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
         mock_client.get.assert_has_calls(calls)
         self.assertEqual(states.ERROR, pstate)
 
-    @mock.patch("oslo_utils.eventletutils.EventletEvent.wait", autospec=True)
-    def test_power_reset_on_timeout(self, mock_sleep, mock_get_client):
+    def test_power_reset_on_timeout(self, mock_get_client):
         # Ensure that a power on consistency poll timeout during a reset
         # causes an error
         mock_client = mock_get_client.return_value
